<?php

/**
 * Content of the latest posts
 *
 * @package ContentOfLatestPosts
 * @version 2.4
 * @author davidhs
 * @copyright 2010-2018 by davidhs
 * @license Creative Commons Attribution 3.0 Unported License https://creativecommons.org/licenses/by/3.0/
 */

if (!defined('SMF'))
	die('Hacking attempt...');

// Returns boards and children boards.
function colpAddChildrenBoards($board_array, $child_boards)
{
	global $db_prefix;

	if ((!is_numeric($child_boards) || !empty($child_boards)) && !empty($board_array))
	{
		$request = db_query("
			SELECT ID_BOARD
			FROM {$db_prefix}boards
			WHERE ID_PARENT IN (" . implode(',', $board_array) . ")", __FILE__, __LINE__);
		$child_array = array();
		while ($row = mysql_fetch_assoc($request))
			$child_array[] = $row['ID_BOARD'];
		mysql_free_result($request);

		if (is_numeric($child_boards))
			$child_boards--;
		$child_array = colpAddChildrenBoards($child_array, $child_boards);
		$board_array = array_merge($board_array, $child_array);
	}
	return $board_array;
}

// Gets earliest message id.
function colpGetEarliestMsg($boards)
{
	global $db_prefix, $ID_MEMBER, $user_info, $modSettings;

	$cond_array = array();
	$cond_array[] = '(' . $user_info['query_see_board'] . ')';
	if ('all' == $boards)
	{
		if (!empty($modSettings['recycle_enable']))
			$cond_array[] = '(b.ID_BOARD <> ' . $modSettings['recycle_board'] . ')';
	}
	elseif (is_numeric($boards))
		$cond_array[] = '(b.ID_BOARD = ' . $boards . ')';
	else
		$cond_array[] = '(b.ID_BOARD IN (' . $boards .'))';
	$cond = implode(' AND ', $cond_array);

	$request = db_query("
		SELECT MIN(lmr.ID_MSG)
		FROM {$db_prefix}boards AS b
			LEFT JOIN {$db_prefix}log_mark_read AS lmr ON (lmr.ID_BOARD = b.ID_BOARD AND lmr.ID_MEMBER = $ID_MEMBER)
		WHERE $cond", __FILE__, __LINE__);
	list ($earliest_msg) = mysql_fetch_row($request);
	mysql_free_result($request);

	// This is needed in case of topics marked unread.
	if (empty($earliest_msg))
		$earliest_msg = 0;
	else
	{
		// Using caching, when possible, to ignore the below slow query.
		if (isset($_SESSION['cached_log_time']) && $_SESSION['cached_log_time'][0] + 45 > time())
			$earliest_msg2 = $_SESSION['cached_log_time'][1];
		else
		{
			// This query is pretty slow, but it's needed to ensure nothing crucial is ignored.
			$request = db_query("
				SELECT MIN(ID_MSG)
				FROM {$db_prefix}log_topics
				WHERE ID_MEMBER = $ID_MEMBER", __FILE__, __LINE__);
			list ($earliest_msg2) = mysql_fetch_row($request);
			mysql_free_result($request);

			// In theory this could be zero, if the first ever post is unread, so fudge it ;)
			if ($earliest_msg2 == 0)
				$earliest_msg2 = -1;

			$_SESSION['cached_log_time'] = array(time(), $earliest_msg2);
		}

		$earliest_msg = min($earliest_msg2, $earliest_msg);
	}

	return $earliest_msg;
}

// Gets key of index of first character of string.
function colpGetKeyIndexFirstCharacter($string, $letters_single, $letters_combi, $prefix = array())
{
	global $func;

	$string = trim($string);

	// Remove prefix on string.
	foreach ($prefix as $pre)
	{
		if (0 === $func['strpos']($string, $pre))
		{
			$string = trim($func['substr']($string, $func['strlen']($pre)));
			break; // Exit foreach.
		}
	}

	// Search key.
	$key = '';
	if (0 < $func['strlen']($string))
	{
		$string = $func['strtoupper'](un_htmlspecialchars($string));
		$letters_combi = array_map('un_htmlspecialchars', $letters_combi);
		$letters_single = array_map('un_htmlspecialchars', $letters_single);

		// Search combination of letters.
		foreach ($letters_combi as $i => $letter)
		{
			if (0 === $func['strpos']($string, $letter))
			{
				$key = $i;
				break; // Exit foreach.
			}
		}

		// Search single letters without and with accent.
		if (!is_numeric($key))
		{
			$char = $func['substr']($string, 0, 1);
			$i = array_search($char, $letters_single);
			if (is_numeric($i))
				$key = $i;
			else
			{
				$char_woa = colp_wp_remove_accents($char);
				$i = array_search($char_woa, $letters_single);
				if (is_numeric($i))
					$key = $i;
			}
		}

		// Is number or symbol.
		if (!is_numeric($key))
			$key = is_numeric($char) ? 'number' : 'symbol';
	}

	return $key;
}

// Gets settings.
function colpGetSettings($id = null)
{
	global $modSettings;

	$default_settings = array(
		'description' => '',
		'header' => '',
		'not_content' => '',
		'type' => 'all',
		'boards' => 'current',
		'child_boards' => '0',
		'group' => 'board',
		'group_letters' => '',
		'group_prefix' => '',
		'show_boards' => '1',
		'show_icon' => '1',
		'show_subject' => '1',
		'show_poster' => '1',
		'show_content' => '1',
		'format_type' => 'html',
		'format_gr_begin' => '',
		'format_content' => '',
		'format_gr_end' => '',
		'order_by' => 'date_desc',
		'boards_link' => 'all',
		'number_by_group' => '0',
		'number_by_topic' => '0',
		'age' => '0',
		'unread' => 'no',
		'date' => 'create',
		'sticky' => 'all',
		'locked' => 'all',
		'first_post_topic' => '1',
		'replies_topic' => '1',
		'subject_prefix' => '',
		'no_subject_prefix' => '',
	);

	$ids = !empty($modSettings['colp_predefined_ids']) ? explode(',', $modSettings['colp_predefined_ids']) : array();

	$colp_settings = array();
	if (empty($id))
		$colp_settings = $default_settings;
	elseif ('default' == $id || is_numeric($id))
	{
		if (('default' == $id && isset($modSettings['colp_default_type'])) || (is_numeric($id) && in_array($id, $ids)))
		{
			$id2 = $id;
			if (is_numeric($id2))
				$id2 = 'predefined_' . $id2;

			$colp_settings['id'] = $id;
			foreach ($default_settings as $param => $v)
				$colp_settings[$param] = isset($modSettings['colp_' . $id2 . '_' . $param]) ? $modSettings['colp_' . $id2 . '_' . $param] : $v;
		}
	}
	elseif (!empty($ids)) // $id = predefined.
	{
		foreach ($ids as $id)
			$colp_settings[] = colpGetSettings($id);
	}

	return $colp_settings;
}

// Indicates if is a combination of characters.
function colpIsCharacterCombination($char)
{
	global $func;

	return 1 < $func['strlen']($char);
}

// Indicates if is a single character.
function colpIsCharacterSingle($char)
{
	global $func;

	return 1 == $func['strlen']($char);
}

// Indicates if is not an empty string.
function colpIsNotEmptyString($string)
{
	return !empty($string) || is_numeric($string);
}

// Returns BBC with content latest.
function colpParseBbcContentlatest($data, $smileys, $cache_id, $predefined = null, $type = null, $group = null, $boards_link = null, $boards = null, $child_boards = null, $number_by_group = null, $number_by_topic = null, $age = null, $unread = null, $date = null, $sticky = null, $locked = null)
{
	global $db_prefix, $func, $context, $txt, $ID_MEMBER, $user_info, $settings, $modSettings, $board, $scripturl;

	loadTemplate('ContentOfLatestPosts');

	// Parameters.
	$colp_default_settings = colpGetSettings('default');
	if (empty($colp_default_settings))
		$colp_default_settings = colpGetSettings();

	if (!empty($predefined))
	{
		$colp_predefined_settings = colpGetSettings($predefined);
		if (!empty($colp_predefined_settings))
			$colp_default_settings = $colp_predefined_settings;
	}

	$header = !empty($colp_default_settings['header']) ? $func['htmlspecialchars']($colp_default_settings['header'], ENT_QUOTES) : '{TITLE}';
	$not_content = !empty($colp_default_settings['not_content']) ? $colp_default_settings['not_content'] : $txt['colp_not_content_text'];
	$not_content = $func['htmlspecialchars']($not_content, ENT_QUOTES);

	if (empty($type))
		$type = $colp_default_settings['type'];
	if (empty($group))
		$group = $colp_default_settings['group'];
	elseif ('yes' == $group) // "yes" is still supported for backward compatibility ("yes" = "board").
		$group = 'board';
	$show_boards = 'board' == $group ? 1 : $colp_default_settings['show_boards'];
	$show_icon = $colp_default_settings['show_icon'];
	$show_subject = 'subject' == $type ? 1 : $colp_default_settings['show_subject'];
	$show_poster = $colp_default_settings['show_poster'];
	if ('subject' == $type)
		$show_content = 0;
	else
		$show_content = in_array($type, array('all', 'post')) ? 1 : $colp_default_settings['show_content'];
	$format_type = $colp_default_settings['format_type'];
	$format_gr_begin = $colp_default_settings['format_gr_begin'];
	$format_content = $colp_default_settings['format_content'];
	$format_gr_end = $colp_default_settings['format_gr_end'];
	if (empty($boards_link))
		$boards_link = $colp_default_settings['boards_link'];
	if (empty($boards))
		$boards = $colp_default_settings['boards'];
	if (empty($child_boards))
		$child_boards = $colp_default_settings['child_boards'];
	elseif ('all' == $child_boards)
		$child_boards = '';
	$order_by = $colp_default_settings['order_by'];
	if ('all' == $number_by_group) // "all" is still supported for backward compatibility ("all" = 0).
		$number_by_group = 0;
	elseif (!is_numeric($number_by_group))
		$number_by_group = $colp_default_settings['number_by_group'];
	if ('all' == $number_by_topic) // "all" is still supported for backward compatibility ("all" = 0).
		$number_by_topic = 0;
	elseif (!is_numeric($number_by_topic))
		$number_by_topic = $colp_default_settings['number_by_topic'];
	if (!is_numeric($age))
		$age = $colp_default_settings['age'];
	if ($user_info['is_guest'])
		$unread = 'no';
	elseif (empty($unread))
		$unread = $colp_default_settings['unread'];
	if (empty($date))
		$date = $colp_default_settings['date'];
	if (empty($sticky))
		$sticky = $colp_default_settings['sticky'];
	if (empty($locked))
		$locked = $colp_default_settings['locked'];
	$first_post_topic = $colp_default_settings['first_post_topic'];
	$replies_topic = $colp_default_settings['replies_topic'];
	$subject_prefix = !empty($colp_default_settings['subject_prefix']) ? explode(',', $colp_default_settings['subject_prefix']) : array();
	$no_subject_prefix = !empty($colp_default_settings['no_subject_prefix']) ? explode(',', $colp_default_settings['no_subject_prefix']) : array();

	if ('all' != $boards)
	{
		if ('current' == $boards)
			$boards = $board;

		if (!is_numeric($boards))
		{
			$board_array = array_map('trim', explode(',', $boards));
			$board_array = array_unique($board_array);
			foreach ($board_array as $i => $v)
			{
				if (!is_numeric($v) || empty($v))
					unset($board_array[$i]);
			}
		}
		else
			$board_array = array($boards);

		if (!empty($board_array))
		{
			$board_array = colpAddChildrenBoards($board_array, $child_boards);
			$boards = implode(',', $board_array);
		}
		else
			$boards = '0';
	}

	if ('character' == $group)
	{
		if (!empty($colp_default_settings['group_letters']))
			$group_letters = $colp_default_settings['group_letters'];
		else
		{
			$group_letters = array_map('trim', explode(',', $func['strtoupper']($txt['colp_group_letters_alphabet'])));
			$group_letters = array_filter($group_letters, 'colpIsNotEmptyString');
			$group_letters = array_unique($group_letters);
			$group_letters = $func['htmlspecialchars'](implode(',', $group_letters), ENT_QUOTES);
		}
		$group_letters = explode(',', $group_letters);
		$group_letters_single = array_filter($group_letters, 'colpIsCharacterSingle');
		$group_letters_combi = array_filter($group_letters, 'colpIsCharacterCombination');

		$group_prefix = !empty($colp_default_settings['group_prefix']) ? explode(',', $colp_default_settings['group_prefix']) : array();
	}

	// Posts.
	$have_content = 'subject' != $type;
	$seach_like = colpSearch($type, 'like');
	$attr = 'm.ID_MSG, m.ID_TOPIC, m.ID_BOARD, m.posterTime, m.subject, m.ID_MEMBER, m.posterName, m.icon, mem.memberName, t.ID_FIRST_MSG';
	if ($have_content)
		$attr .= ', m.body, m.smileysEnabled';

	$cond_array = array();
	if (!empty($seach_like))
		$cond_array[] = '((m.body LIKE \'' . implode('\') OR (m.body LIKE \'', $seach_like) . '\'))';
	$cond_array[] = '(' . $user_info['query_see_board'] . ')';
	if ('all' == $boards)
	{
		if (!empty($modSettings['recycle_enable']))
			$cond_array[] = '(t.ID_BOARD <> ' . $modSettings['recycle_board'] . ')';
	}
	elseif (is_numeric($boards))
		$cond_array[] = '(t.ID_BOARD = ' . $boards . ')';
	else
		$cond_array[] = '(t.ID_BOARD IN (' . $boards .'))';
	$sql_date = ('modify' == $date) ? 'IF(0 = m.modifiedTime, m.posterTime, m.modifiedTime)' : 'm.posterTime';
	$cond_array[] = '((UNIX_TIMESTAMP() - ' . $sql_date . ') / 86400 <= ' . $age . ')';
	switch ($unread)
	{
		case 'new':
		{
			$join = "
			LEFT JOIN {$db_prefix}log_topics AS lt ON (lt.ID_TOPIC = t.ID_TOPIC AND lt.ID_MEMBER = $ID_MEMBER)
			LEFT JOIN {$db_prefix}log_mark_read AS lmr ON (lmr.ID_BOARD = t.ID_BOARD AND lmr.ID_MEMBER = $ID_MEMBER)";
			$cond_array[] = '(t.ID_LAST_MSG > ' . $_SESSION['ID_MSG_LAST_VISIT'] . ')';
			$cond_array[] = '(IFNULL(lt.ID_MSG, IFNULL(lmr.ID_MSG, 0)) < t.ID_LAST_MSG)';
			break;
		}
		case 'all':
		{
			if (!empty($context['load_average']) && !empty($modSettings['loadavg_allunread']) && $context['load_average'] >= $modSettings['loadavg_allunread'])
				fatal_lang_error('loadavg_allunread_disabled', false);

			$join = "
			LEFT JOIN {$db_prefix}log_topics AS lt ON (lt.ID_TOPIC = t.ID_TOPIC AND lt.ID_MEMBER = $ID_MEMBER)
			LEFT JOIN {$db_prefix}log_mark_read AS lmr ON (lmr.ID_BOARD = t.ID_BOARD AND lmr.ID_MEMBER = $ID_MEMBER)";
			$earliest_msg = colpGetEarliestMsg($boards);
			if (!empty($earliest_msg))
				$cond_array[] = '(t.ID_LAST_MSG > ' . $earliest_msg . ')';
			else
				$cond_array[] = '(t.ID_LAST_MSG > ' . $_SESSION['ID_MSG_LAST_VISIT'] . ')';
			$cond_array[] = '(IFNULL(lt.ID_MSG, IFNULL(lmr.ID_MSG, 0)) < t.ID_LAST_MSG)';
			break;
		}
		case 'replies':
		{
			if (!empty($context['load_average']) && !empty($modSettings['loadavg_unreadreplies']) && $context['load_average'] >= $modSettings['loadavg_unreadreplies'])
				fatal_lang_error('loadavg_unreadreplies_disabled', false);

			$attr = 'DISTINCT ' . $attr;
			$join = "
			INNER JOIN {$db_prefix}messages AS m2 ON (m2.ID_TOPIC = t.ID_TOPIC)
			LEFT JOIN {$db_prefix}log_topics AS lt ON (lt.ID_TOPIC = t.ID_TOPIC AND lt.ID_MEMBER = $ID_MEMBER)
			LEFT JOIN {$db_prefix}log_mark_read AS lmr ON (lmr.ID_BOARD = t.ID_BOARD AND lmr.ID_MEMBER = $ID_MEMBER)";
			$cond_array[] = '(m2.ID_MEMBER = ' . $ID_MEMBER . ')';
			$cond_array[] = '(IFNULL(lt.ID_MSG, IFNULL(lmr.ID_MSG, 0)) < t.ID_LAST_MSG)';
			break;
		}
		case 'no': default:
		{
			$join = '';
			break;
		}
	}
	if ('all' != $locked)
		$cond_array[] = '(t.locked = ' . ('yes' == $locked ? 1 : 0) . ')';
	if ('all' != $sticky)
		$cond_array[] = '(t.isSticky = ' . ('yes' == $sticky ? 1 : 0) . ')';
	if (!$first_post_topic)
		$cond_array[] = '(m.ID_MSG <> t.ID_FIRST_MSG)';
	if (!$replies_topic)
		$cond_array[] = '(m.ID_MSG = t.ID_FIRST_MSG)';
	if (!empty($subject_prefix))
	{
		$cond_array2 = array();
		foreach ($subject_prefix as $prefix)
			$cond_array2[] = '(m.subject LIKE \'' . addslashes($prefix) . '%\')';
		$cond_array[] = '(' . implode(' OR ', $cond_array2) . ')';
	}
	foreach ($no_subject_prefix as $prefix)
		$cond_array[] = '(m.subject NOT LIKE \'' . addslashes($prefix) . '%\')';
	$cond = implode(' AND ', $cond_array);

	if ('date_desc' == $order_by)
		$order_by2 = 'm.posterTime ' . (!empty($number_by_topic) ? 'ASC' : 'DESC');
	else // subject_asc.
		$order_by2 = 'm.subject ' . (!empty($number_by_topic) ? 'DESC' : 'ASC');

	$request = db_query("
		SELECT $attr
		FROM {$db_prefix}topics AS t
			INNER JOIN {$db_prefix}boards AS b ON (b.ID_BOARD = t.ID_BOARD)
			INNER JOIN {$db_prefix}messages AS m ON (m.ID_TOPIC = t.ID_TOPIC)
			LEFT JOIN {$db_prefix}members AS mem ON (mem.ID_MEMBER = m.ID_MEMBER)$join
		WHERE $cond
		ORDER BY $order_by2", __FILE__, __LINE__);

	$function = 'colpParseBbcType' . ucfirst($type);
	$post_array = array();
	$id_board_array = array();
	$number_by_topic_array = array();
	while ($row = mysql_fetch_assoc($request))
	{
		$row['subject'] = censorText($row['subject']);
		if ('character' == $group)
		{
			$key = colpGetKeyIndexFirstCharacter($row['subject'], $group_letters_single, $group_letters_combi, $group_prefix);
			if (empty($key) && !is_numeric($key))
				$key = 'symbol';
		}

		if (!empty($number_by_group))
		{
			switch ($group)
			{
				case 'no':
				{
					if (count($post_array) >= $number_by_group)
						break 2; // Exit while.
					break;
				}
				case 'board':
				{
					if (!empty($post_array[$row['ID_BOARD']]) && (count($post_array[$row['ID_BOARD']]) >= $number_by_group))
						continue; // Skip row.
					break;
				}
				case 'character':
				{
					if (!empty($post_array[$key]) && (count($post_array[$key]) >= $number_by_group))
						continue; // Skip row.
					break;
				}
			}
		}

		if (!empty($number_by_topic))
		{
			if (!empty($number_by_topic_array[$row['ID_TOPIC']]) && ($number_by_topic_array[$row['ID_TOPIC']] >= $number_by_topic))
				continue; // Skip row.
		}

		$content_format_content = $have_content ? $function($row, 1) : '';

		// Instead of: $content = $have_content ? $function($row, $show_content) : '';
		// Set $content with $content_format_content and $show_content.
		$content = $content_format_content;
		if (!$show_content && (!empty($content) || is_numeric($content)))
			$content = 1;

		if (!$have_content || !empty($content) || is_numeric($content))
		{
			$images_url = file_exists($settings['theme_dir'] . '/images/post/' . $row['icon'] . '.gif') ? 'images_url' : 'default_images_url';
			$icon_url = $settings[$images_url] . '/post/' . $row['icon'] . '.gif';

			if (!empty($format_content))
			{
				$row['format_content_trans'] = array(
					'{ICON_URL}' => $icon_url,
					'{SUBJECT}' => addslashes($row['subject']),
					'{ID_POSTER}' => $row['ID_MEMBER'],
					'{POSTER_NAME}' => $row['ID_MEMBER'] ? $row['memberName'] : $row['posterName'],
					'{POSTER_TIME}' => timeformat($row['posterTime']),
					'{CONTENT}' => $content_format_content,
					'{ID_MSG}' => $row['ID_MSG'],
					'{ID_TOPIC}' => $row['ID_TOPIC'],
					'{ID_BOARD}' => $row['ID_BOARD'],
					'{ID_FIRST_MSG}' => $row['ID_FIRST_MSG'],
				);
			}

			if ($show_icon)
				$row['icon_url'] = $icon_url;
			else
				unset($row['icon']);
			if ($show_poster)
			{
				if ($row['ID_MEMBER'])
					$row['profile_url'] = $scripturl . '?action=profile;u=' . $row['ID_MEMBER'];
				$row['time'] = timeformat($row['posterTime']);
			}
			if ($show_subject)
				$row['href'] = $scripturl . '?topic=' . $row['ID_TOPIC'] . '.msg' . $row['ID_MSG'] . '#msg' . $row['ID_MSG'];
			else
				unset($row['subject']);
			if ($show_content)
				$row['content'] = $content;

			$id_board_array[] = $row['ID_BOARD'];
			switch ($group)
			{
				case 'no':
				{
					$post_array[] = $row;
					break;
				}
				case 'board':
				{
					$post_array[$row['ID_BOARD']][] = $row;
					break;
				}
				case 'character':
				{
					$post_array[$key][] = $row;
					break;
				}
			}

			if (!empty($number_by_topic))
			{
				if (empty($number_by_topic_array[$row['ID_TOPIC']]))
					$number_by_topic_array[$row['ID_TOPIC']] = 0;
				$number_by_topic_array[$row['ID_TOPIC']]++;
			}
		}
	}
	mysql_free_result($request);

	// Correct order if exists number posts by topic.
	if (!empty($post_array) && !empty($number_by_topic))
	{
		switch ($group)
		{
			case 'no':
			{
				$post_array = array_reverse($post_array);
				break;
			}
			case 'board':
			case 'character':
			{
				foreach ($post_array as $i => $msg_array)
					$post_array[$i] = array_reverse($msg_array);
				break;
			}
		}
	}

	// Set format at the beginning/ending of each group of contents.
	$format_gr = array();
	if (!empty($post_array))
	{
		switch ($group)
		{
			case 'no':
			{
				$format_gr['format_gr_begin'] = colpParseFormat($format_gr_begin, $format_type, $type);
				if (!empty($format_content))
				{
					foreach ($post_array as $i => $row)
						$post_array[$i]['format_content'] = colpParseFormat($format_content, $format_type, $type, $row['format_content_trans']);
				}
				$format_gr['format_gr_end'] = colpParseFormat($format_gr_end, $format_type, $type);
				break;
			}
			case 'board':
			case 'character':
			{
				foreach ($post_array as $i => $msg_array)
				{
					$format_gr[$i]['format_gr_begin'] = colpParseFormat($format_gr_begin, $format_type, $type);
					if (!empty($format_content))
					{
						foreach ($msg_array as $j => $row)
							$post_array[$i][$j]['format_content'] = colpParseFormat($format_content, $format_type, $type, $row['format_content_trans']);
					}
					$format_gr[$i]['format_gr_end'] = colpParseFormat($format_gr_end, $format_type, $type);
				}
				break;
			}
		}
	}
	if (empty($format_gr))
	{
		$format_gr = array(
			'format_gr_begin' => colpParseFormat($format_gr_begin, $format_type, $type),
			'format_gr_end' => colpParseFormat($format_gr_end, $format_type, $type),
		);
	}

	// Boards.
	$board_array = array();
	if ($show_boards)
	{
		$top = array('name' => $context['forum_name']);
		if ('all' == $boards_link)
			$top['url'] = $scripturl;
		if (!empty($post_array))
		{
			$request = db_query("
				SELECT ID_BOARD, ID_CAT, ID_PARENT, name
				FROM {$db_prefix}boards
				WHERE ID_BOARD IN (" . implode(',', array_unique($id_board_array)) . ")
				ORDER BY boardOrder ASC", __FILE__, __LINE__);
			while ($row = mysql_fetch_assoc($request))
			{
				if ('no' != $boards_link)
					$row['url'] = $scripturl . '?board=' . $row['ID_BOARD'] . '.0';
				$board_array[$row['ID_BOARD']][] = $row;

				$row2 = $row;
				while ($row2['ID_PARENT'])
				{
					$request2 = db_query("
						SELECT ID_BOARD, ID_CAT, ID_PARENT, name
						FROM {$db_prefix}boards
						WHERE ID_BOARD = " . $row2['ID_PARENT'], __FILE__, __LINE__);
					$row2 = mysql_fetch_assoc($request2);
					mysql_free_result($request2);

					if ('all' == $boards_link)
						$row2['url'] = $scripturl . '?board=' . $row2['ID_BOARD'] . '.0';
					$board_array[$row['ID_BOARD']][] = $row2;
				}

				if ($row2['ID_CAT'])
				{
					$request2 = db_query("
						SELECT ID_CAT, name
						FROM {$db_prefix}categories
						WHERE ID_CAT = " . $row2['ID_CAT'], __FILE__, __LINE__);
					$row2 = mysql_fetch_assoc($request2);
					mysql_free_result($request2);

					if ('all' == $boards_link)
						$row2['url'] = $scripturl . '#' . $row2['ID_CAT'];
					$board_array[$row['ID_BOARD']][] = $row2;
				}

				$board_array[$row['ID_BOARD']][] = $top;
				$board_array[$row['ID_BOARD']] = array_reverse($board_array[$row['ID_BOARD']]);
			}
			mysql_free_result($request);
		}
	}

	// Characters.
	$char_array = array();
	if ('character' == $group)
	{
		$keys = array_merge(array('symbol', 'number'), array_keys($group_letters));
		foreach ($keys as $key)
		{
			$char_array[$key] = array('text' => is_numeric($key) ? $group_letters[$key] : $txt['colp_' . $key . 's']);
			if (isset($post_array[$key]))
			{
				$char_array[$key]['url'] = '#colp_index_' . $key;
				$char_array[$key]['name'] = 'colp_index_' . $key;
			}
		}
	}

	return
		colpParseBbcHeader($header, $data, $smileys, $cache_id, $type) .
		template_colp_get($group, $board_array, $char_array, $format_gr, $post_array, $not_content);
}

// Returns BBC with header.
function colpParseBbcHeader($header, $data, $smileys, $cache_id, $type)
{
	global $settings, $boardurl, $scripturl;

	$trans = array(
		'{TITLE}' => $data,
	);
	$header = strtr($header, $trans);

	$trans = array(
		'{TYPE}' => colpSearch($type, 'name'),
		'{BOARDURL}' => $boardurl,
		'{SCRIPTURL}' => $scripturl,
		'{IMAGES_URL}' => $settings['images_url'],
		'{DEFAULT_IMAGES_URL}' => $settings['default_images_url'],
	);
	$header = strtr($header, $trans);

	if (0 === strpos($header, 'http://'))
		$header = '[img]' . $header . '[/img]';

	return parse_bbc(censorText($header), $smileys, $cache_id);
}

// Returns BBC with content latest of all type.
function colpParseBbcTypeAll($row, $show_content)
{
	return colpParseBbcTypePost($row, $show_content) . colpParseBbcTypeAttachment($row, $show_content);
}

// Returns BBC with content latest of post type.
function colpParseBbcTypePost($row, $show_content)
{
	if ($show_content)
	{
		$body = str_replace('[contentlatest', '[ contentlatest', $row['body']);
		$content = parse_bbc(censorText($body), $row['smileysEnabled'], $row['ID_MSG']);
	}
	else
		$content = '1';

	return $content;
}

// Returns BBC with content latest of attachment type.
function colpParseBbcTypeAttachment($row, $show_content)
{
	global $sourcedir, $modSettings;

	$content = '';
	if (!empty($modSettings['attachmentEnable']) && allowedTo('view_attachments'))
	{
		$allAttachments = colpGetAttachsByMsg($row['ID_MSG']);
		$attachments2 = array($row['ID_MSG'] => $allAttachments[$row['ID_MSG']]);

		if (!empty($attachments2))
		{
			if ($show_content)
			{
				global $topic, $attachments;
				if (isset($topic))
					$topic_orig = $topic;
				$topic = $row['ID_TOPIC'];
				if (isset($attachments))
					$attachments_orig = $attachments;
				$attachments = $attachments2;

				require_once ($sourcedir . '/Display.php');
				$attach_array = loadAttachmentContext($row['ID_MSG']);

				if (isset($attachments_orig))
					$attachments = $attachments_orig;
				else
					unset($attachments);
				if (isset($topic_orig))
					$topic = $topic_orig;
				else
					unset($topic);

				$content = template_colp_get_type_attachment($attach_array);
				// $content is HTML code.
				// $content = parse_bbc($content, $row['smileysEnabled'], $row['ID_MSG']);
			}
			else
				$content = '1';
		}
	}

	return $content;
}

// Gets attachment info associated with a message ID.
function colpGetAttachsByMsg($msgID = 0)
{
	global $db_prefix, $modSettings;
	static $attached = array();

	if (!isset($attached[$msgID]))
	{
		$request = db_query("
			SELECT
				a.ID_ATTACH, a.ID_MSG, a.filename, IFNULL(a.size, 0) AS filesize, a.downloads,
				a.width, a.height" . (empty($modSettings['attachmentShowImages']) || empty($modSettings['attachmentThumbnails']) ? '' : ",
				IFNULL(thumb.ID_ATTACH, 0) AS ID_THUMB, thumb.width AS thumb_width, thumb.height AS thumb_height") . "
			FROM {$db_prefix}attachments AS a" . (empty($modSettings['attachmentShowImages']) || empty($modSettings['attachmentThumbnails']) ? '' : "
				LEFT JOIN {$db_prefix}attachments AS thumb ON (thumb.ID_ATTACH = a.ID_THUMB)") . "
			WHERE a.attachmentType = 0" . (empty($msgID) ? '' : "
				AND a.ID_MSG = $msgID"), __FILE__, __LINE__);
		$temp = array();
		while ($row = mysql_fetch_assoc($request))
			$temp[$row['ID_ATTACH']] = $row;
		mysql_free_result($request);

		// This is better than sorting it with the query...
		ksort($temp);

		$attached[$msgID] = $temp;
	}

	return $attached;
}

// Returns BBC with content latest of link type.
function colpParseBbcTypeLink($row, $show_content)
{
	global $context;

	$link_array = array();
	$pattern_array = colpSearch('link', 'pattern');
	$pattern0 = array_shift($pattern_array);
	foreach ($pattern_array as $pattern)
	{
		if (preg_match_all($pattern, $row['body'], $parts))
		{
			foreach ($parts[1] as $i => $link)
				$link_array[$link] = $parts[0][$i];
			if (!$show_content)
				break; // Exit foreach.
		}
	}
	$body = strtr($row['body'], array('&#039;' => '\'', '&nbsp;' => $context['utf8'] ? "\xC2\xA0" : "\xA0", '&quot;' => '>">', '"' => '<"<', '&lt;' => '<lt<'));
	if (preg_match_all($pattern0, $body, $parts))
	{
		foreach ($parts[1] as $i => $link)
		{
			if (!isset($link_array[$link]))
			{
				foreach ($link_array as $text)
				{
					if (!(false === strpos($text, $link)))
						break 2; // Exit foreach $parts[1].
				}
				$link_array[$link] = $parts[0][$i];
				if (!$show_content)
					break; // Exit foreach.
			}
		}
	}

	$content = '';
	if (!empty($link_array))
	{
		if ($show_content)
		{
			$content = template_colp_get_type_link($link_array);
			$content = parse_bbc($content, $row['smileysEnabled'], $row['ID_MSG']);
		}
		else
			$content = '1';
	}

	return $content;
}

// Returns BBC with content latest of elink type.
function colpParseBbcTypeElink($row, $show_content)
{
	$elink_array = array();
	$pattern = colpSearch('elink', 'pattern');
	if (preg_match_all($pattern, $row['body'], $parts))
	{
		foreach ($parts[1] as $i => $elink)
			$elink_array[$elink] = $parts[2][$i];
	}

	$content = '';
	if (!empty($elink_array))
	{
		if ($show_content)
		{
			$content = template_colp_get_type_elink($elink_array);
			$content = parse_bbc($content, $row['smileysEnabled'], $row['ID_MSG']);
		}
		else
			$content = '1';
	}

	return $content;
}

// Returns BBC with content latest of image type.
function colpParseBbcTypeImage($row, $show_content)
{
	$img_array = array();
	$pattern_array = colpSearch('image', 'pattern');
	foreach ($pattern_array as $pattern)
	{
		if (preg_match_all($pattern, $row['body'], $parts))
		{
			foreach ($parts[1] as $i => $src)
				$img_array[$src] = $parts[0][$i];
			if (!$show_content)
				break; // Exit foreach.
		}
	}

	$content = '';
	if (!empty($img_array))
	{
		if ($show_content)
		{
			$content = template_colp_get_type_image($img_array);
			$content = parse_bbc($content, $row['smileysEnabled'], $row['ID_MSG']);
		}
		else
			$content = '1';
	}

	return $content;
}

// Returns HTML code with show text.
function colpParseFormat($format_content, $format_type, $type, $trans = array())
{
	global $boardurl, $scripturl, $settings;

	$trans = array_merge($trans, array(
		'{TYPE_CODE}' => $type,
		'{TYPE_TXT}' => colpSearch($type, 'name'),
		'{BOARDURL}' => $boardurl,
		'{SCRIPTURL}' => $scripturl,
		'{IMAGES_URL}' => $settings['images_url'],
		'{DEFAULT_IMAGES_URL}' => $settings['default_images_url'],
	));
	$format_content = strtr($format_content, $trans);

	switch ($format_type)
	{
		case 'bbc':
		{
			$format_content = parse_bbc(censorText($format_content));
			break;
		}
		case 'php':
		{
			$format_content = trim($format_content);

			if ('<?php' == substr($format_content, 0, 5))
				$format_content = substr($format_content, 5);
			if ('?>' == substr($format_content, -2))
				$format_content = substr($format_content, 0, -2);

			ob_start();
			colpEval($format_content);
			$format_content = ob_get_contents();
			ob_end_clean();
			break;
		}
		case 'html':
		default:
		{
			// VOID
			break;
		}
	}

	return $format_content;
}

// Evaluates PHP code.
function colpEval($colp_eval)
{
	eval($colp_eval);
}

// Returns search data of type and key.
function colpSearch($type = '', $key = '')
{
	global $txt;
	static $search_data = array();

	if (empty($search_data))
	{
		$search_data = array(
			'all' => array(),
			'post' => array(),
			'subject' => array(),
			'attachment' => array(),
			'link' => array(
				'like' => array('%http://%', '%https://%', '%ftp://%', '%ftps://%'),
				'pattern' => array(
					'~((?:http|https)://[\w\-_%@:|]+(?:\.[\w\-_%]+)*(?::\d+)?(?:/[\w\-_\~%\.@,\?&;=#(){}+:\'\\\\]*)*[/\w\-_\~%@\?;=#}\\\\])~i',
					'~((?:ftp|ftps)://[\w\-_%@:|]+(?:\.[\w\-_%]+)*(?::\d+)?(?:/[\w\-_\~%\.@,\?&;=#(){}+:\'\\\\]*)*[/\w\-_\~%@\?;=#}\\\\])~i',
					'~\[url\](.+?)\[/url\]~i',
					'~\[url=(.+?)\](.+?)\[/url\]~i',
					'~\[iurl\](.+?)\[/iurl\]~i',
					'~\[iurl=(.+?)\](.+?)\[/iurl\]~i',
					'~&lt;a\s+href=(?:&quot;)?((?:http://|ftp://|https://|ftps://).+?)(?:&quot;)?&gt;(.+?)&lt;/a&gt;~i'
				)
			),
			'elink' => array(
				'like' => array('%ed2k://|file|%'),
				'pattern' => '~(ed2k://\|file\|(.+?)\|.+?)(?:&quot;|"|<|\s|$)~i'
			),
			'image' => array(
				'like' => array('%&lt;img %', '%[img]%'),
				'pattern' => array(
					'~\[img.*?\](.+?)\[/img\]~i',
					'~&lt;img\s+src=(?:&quot;)?((?:http://|ftp://|https://|ftps://).+?)(?:&quot;)?(?:\s+alt=(?:&quot;)?(.*?)(?:&quot;)?)?(?:\s?/)?&gt;~i'
				)
			),
		);

		foreach ($search_data as $type2 => $data)
			$search_data[$type2]['name'] = $txt['colp_type_' . $type2];
	}

	$return = array();
	if (!empty($type))
	{
		if (isset($search_data[$type]))
		{
			if (!empty($key))
			{
				if (isset($search_data[$type][$key]))
					$return = $search_data[$type][$key];
			}
			else
				$return = $search_data[$type];
		}
	}
	else
		$return = $search_data;
	return $return;
}

/**
 * Converts all accent characters to ASCII characters.
 *
 * If there are no accent characters, then the string given is just returned.
 *
 * @copyright WordPress
 * @since 1.2.1
 *
 * @param string $string Text that might have accent characters
 * @return string Filtered string with replaced "nice" characters.
 */
function colp_wp_remove_accents($string) {
	if ( !preg_match('/[\x80-\xff]/', $string) )
		return $string;

	if (colp_wp_seems_utf8($string)) {
		$chars = array(
		// Decompositions for Latin-1 Supplement
		chr(194).chr(170) => 'a', chr(194).chr(186) => 'o',
		chr(195).chr(128) => 'A', chr(195).chr(129) => 'A',
		chr(195).chr(130) => 'A', chr(195).chr(131) => 'A',
		chr(195).chr(132) => 'A', chr(195).chr(133) => 'A',
		chr(195).chr(134) => 'AE',chr(195).chr(135) => 'C',
		chr(195).chr(136) => 'E', chr(195).chr(137) => 'E',
		chr(195).chr(138) => 'E', chr(195).chr(139) => 'E',
		chr(195).chr(140) => 'I', chr(195).chr(141) => 'I',
		chr(195).chr(142) => 'I', chr(195).chr(143) => 'I',
		chr(195).chr(144) => 'D', chr(195).chr(145) => 'N',
		chr(195).chr(146) => 'O', chr(195).chr(147) => 'O',
		chr(195).chr(148) => 'O', chr(195).chr(149) => 'O',
		chr(195).chr(150) => 'O', chr(195).chr(153) => 'U',
		chr(195).chr(154) => 'U', chr(195).chr(155) => 'U',
		chr(195).chr(156) => 'U', chr(195).chr(157) => 'Y',
		chr(195).chr(158) => 'TH',chr(195).chr(159) => 's',
		chr(195).chr(160) => 'a', chr(195).chr(161) => 'a',
		chr(195).chr(162) => 'a', chr(195).chr(163) => 'a',
		chr(195).chr(164) => 'a', chr(195).chr(165) => 'a',
		chr(195).chr(166) => 'ae',chr(195).chr(167) => 'c',
		chr(195).chr(168) => 'e', chr(195).chr(169) => 'e',
		chr(195).chr(170) => 'e', chr(195).chr(171) => 'e',
		chr(195).chr(172) => 'i', chr(195).chr(173) => 'i',
		chr(195).chr(174) => 'i', chr(195).chr(175) => 'i',
		chr(195).chr(176) => 'd', chr(195).chr(177) => 'n',
		chr(195).chr(178) => 'o', chr(195).chr(179) => 'o',
		chr(195).chr(180) => 'o', chr(195).chr(181) => 'o',
		chr(195).chr(182) => 'o', chr(195).chr(184) => 'o',
		chr(195).chr(185) => 'u', chr(195).chr(186) => 'u',
		chr(195).chr(187) => 'u', chr(195).chr(188) => 'u',
		chr(195).chr(189) => 'y', chr(195).chr(190) => 'th',
		chr(195).chr(191) => 'y', chr(195).chr(152) => 'O',
		// Decompositions for Latin Extended-A
		chr(196).chr(128) => 'A', chr(196).chr(129) => 'a',
		chr(196).chr(130) => 'A', chr(196).chr(131) => 'a',
		chr(196).chr(132) => 'A', chr(196).chr(133) => 'a',
		chr(196).chr(134) => 'C', chr(196).chr(135) => 'c',
		chr(196).chr(136) => 'C', chr(196).chr(137) => 'c',
		chr(196).chr(138) => 'C', chr(196).chr(139) => 'c',
		chr(196).chr(140) => 'C', chr(196).chr(141) => 'c',
		chr(196).chr(142) => 'D', chr(196).chr(143) => 'd',
		chr(196).chr(144) => 'D', chr(196).chr(145) => 'd',
		chr(196).chr(146) => 'E', chr(196).chr(147) => 'e',
		chr(196).chr(148) => 'E', chr(196).chr(149) => 'e',
		chr(196).chr(150) => 'E', chr(196).chr(151) => 'e',
		chr(196).chr(152) => 'E', chr(196).chr(153) => 'e',
		chr(196).chr(154) => 'E', chr(196).chr(155) => 'e',
		chr(196).chr(156) => 'G', chr(196).chr(157) => 'g',
		chr(196).chr(158) => 'G', chr(196).chr(159) => 'g',
		chr(196).chr(160) => 'G', chr(196).chr(161) => 'g',
		chr(196).chr(162) => 'G', chr(196).chr(163) => 'g',
		chr(196).chr(164) => 'H', chr(196).chr(165) => 'h',
		chr(196).chr(166) => 'H', chr(196).chr(167) => 'h',
		chr(196).chr(168) => 'I', chr(196).chr(169) => 'i',
		chr(196).chr(170) => 'I', chr(196).chr(171) => 'i',
		chr(196).chr(172) => 'I', chr(196).chr(173) => 'i',
		chr(196).chr(174) => 'I', chr(196).chr(175) => 'i',
		chr(196).chr(176) => 'I', chr(196).chr(177) => 'i',
		chr(196).chr(178) => 'IJ',chr(196).chr(179) => 'ij',
		chr(196).chr(180) => 'J', chr(196).chr(181) => 'j',
		chr(196).chr(182) => 'K', chr(196).chr(183) => 'k',
		chr(196).chr(184) => 'k', chr(196).chr(185) => 'L',
		chr(196).chr(186) => 'l', chr(196).chr(187) => 'L',
		chr(196).chr(188) => 'l', chr(196).chr(189) => 'L',
		chr(196).chr(190) => 'l', chr(196).chr(191) => 'L',
		chr(197).chr(128) => 'l', chr(197).chr(129) => 'L',
		chr(197).chr(130) => 'l', chr(197).chr(131) => 'N',
		chr(197).chr(132) => 'n', chr(197).chr(133) => 'N',
		chr(197).chr(134) => 'n', chr(197).chr(135) => 'N',
		chr(197).chr(136) => 'n', chr(197).chr(137) => 'N',
		chr(197).chr(138) => 'n', chr(197).chr(139) => 'N',
		chr(197).chr(140) => 'O', chr(197).chr(141) => 'o',
		chr(197).chr(142) => 'O', chr(197).chr(143) => 'o',
		chr(197).chr(144) => 'O', chr(197).chr(145) => 'o',
		chr(197).chr(146) => 'OE',chr(197).chr(147) => 'oe',
		chr(197).chr(148) => 'R',chr(197).chr(149) => 'r',
		chr(197).chr(150) => 'R',chr(197).chr(151) => 'r',
		chr(197).chr(152) => 'R',chr(197).chr(153) => 'r',
		chr(197).chr(154) => 'S',chr(197).chr(155) => 's',
		chr(197).chr(156) => 'S',chr(197).chr(157) => 's',
		chr(197).chr(158) => 'S',chr(197).chr(159) => 's',
		chr(197).chr(160) => 'S', chr(197).chr(161) => 's',
		chr(197).chr(162) => 'T', chr(197).chr(163) => 't',
		chr(197).chr(164) => 'T', chr(197).chr(165) => 't',
		chr(197).chr(166) => 'T', chr(197).chr(167) => 't',
		chr(197).chr(168) => 'U', chr(197).chr(169) => 'u',
		chr(197).chr(170) => 'U', chr(197).chr(171) => 'u',
		chr(197).chr(172) => 'U', chr(197).chr(173) => 'u',
		chr(197).chr(174) => 'U', chr(197).chr(175) => 'u',
		chr(197).chr(176) => 'U', chr(197).chr(177) => 'u',
		chr(197).chr(178) => 'U', chr(197).chr(179) => 'u',
		chr(197).chr(180) => 'W', chr(197).chr(181) => 'w',
		chr(197).chr(182) => 'Y', chr(197).chr(183) => 'y',
		chr(197).chr(184) => 'Y', chr(197).chr(185) => 'Z',
		chr(197).chr(186) => 'z', chr(197).chr(187) => 'Z',
		chr(197).chr(188) => 'z', chr(197).chr(189) => 'Z',
		chr(197).chr(190) => 'z', chr(197).chr(191) => 's',
		// Decompositions for Latin Extended-B
		chr(200).chr(152) => 'S', chr(200).chr(153) => 's',
		chr(200).chr(154) => 'T', chr(200).chr(155) => 't',
		// Euro Sign
		chr(226).chr(130).chr(172) => 'E',
		// GBP (Pound) Sign
		chr(194).chr(163) => '',
		// Vowels with diacritic (Vietnamese)
		// unmarked
		chr(198).chr(160) => 'O', chr(198).chr(161) => 'o',
		chr(198).chr(175) => 'U', chr(198).chr(176) => 'u',
		// grave accent
		chr(225).chr(186).chr(166) => 'A', chr(225).chr(186).chr(167) => 'a',
		chr(225).chr(186).chr(176) => 'A', chr(225).chr(186).chr(177) => 'a',
		chr(225).chr(187).chr(128) => 'E', chr(225).chr(187).chr(129) => 'e',
		chr(225).chr(187).chr(146) => 'O', chr(225).chr(187).chr(147) => 'o',
		chr(225).chr(187).chr(156) => 'O', chr(225).chr(187).chr(157) => 'o',
		chr(225).chr(187).chr(170) => 'U', chr(225).chr(187).chr(171) => 'u',
		chr(225).chr(187).chr(178) => 'Y', chr(225).chr(187).chr(179) => 'y',
		// hook
		chr(225).chr(186).chr(162) => 'A', chr(225).chr(186).chr(163) => 'a',
		chr(225).chr(186).chr(168) => 'A', chr(225).chr(186).chr(169) => 'a',
		chr(225).chr(186).chr(178) => 'A', chr(225).chr(186).chr(179) => 'a',
		chr(225).chr(186).chr(186) => 'E', chr(225).chr(186).chr(187) => 'e',
		chr(225).chr(187).chr(130) => 'E', chr(225).chr(187).chr(131) => 'e',
		chr(225).chr(187).chr(136) => 'I', chr(225).chr(187).chr(137) => 'i',
		chr(225).chr(187).chr(142) => 'O', chr(225).chr(187).chr(143) => 'o',
		chr(225).chr(187).chr(148) => 'O', chr(225).chr(187).chr(149) => 'o',
		chr(225).chr(187).chr(158) => 'O', chr(225).chr(187).chr(159) => 'o',
		chr(225).chr(187).chr(166) => 'U', chr(225).chr(187).chr(167) => 'u',
		chr(225).chr(187).chr(172) => 'U', chr(225).chr(187).chr(173) => 'u',
		chr(225).chr(187).chr(182) => 'Y', chr(225).chr(187).chr(183) => 'y',
		// tilde
		chr(225).chr(186).chr(170) => 'A', chr(225).chr(186).chr(171) => 'a',
		chr(225).chr(186).chr(180) => 'A', chr(225).chr(186).chr(181) => 'a',
		chr(225).chr(186).chr(188) => 'E', chr(225).chr(186).chr(189) => 'e',
		chr(225).chr(187).chr(132) => 'E', chr(225).chr(187).chr(133) => 'e',
		chr(225).chr(187).chr(150) => 'O', chr(225).chr(187).chr(151) => 'o',
		chr(225).chr(187).chr(160) => 'O', chr(225).chr(187).chr(161) => 'o',
		chr(225).chr(187).chr(174) => 'U', chr(225).chr(187).chr(175) => 'u',
		chr(225).chr(187).chr(184) => 'Y', chr(225).chr(187).chr(185) => 'y',
		// acute accent
		chr(225).chr(186).chr(164) => 'A', chr(225).chr(186).chr(165) => 'a',
		chr(225).chr(186).chr(174) => 'A', chr(225).chr(186).chr(175) => 'a',
		chr(225).chr(186).chr(190) => 'E', chr(225).chr(186).chr(191) => 'e',
		chr(225).chr(187).chr(144) => 'O', chr(225).chr(187).chr(145) => 'o',
		chr(225).chr(187).chr(154) => 'O', chr(225).chr(187).chr(155) => 'o',
		chr(225).chr(187).chr(168) => 'U', chr(225).chr(187).chr(169) => 'u',
		// dot below
		chr(225).chr(186).chr(160) => 'A', chr(225).chr(186).chr(161) => 'a',
		chr(225).chr(186).chr(172) => 'A', chr(225).chr(186).chr(173) => 'a',
		chr(225).chr(186).chr(182) => 'A', chr(225).chr(186).chr(183) => 'a',
		chr(225).chr(186).chr(184) => 'E', chr(225).chr(186).chr(185) => 'e',
		chr(225).chr(187).chr(134) => 'E', chr(225).chr(187).chr(135) => 'e',
		chr(225).chr(187).chr(138) => 'I', chr(225).chr(187).chr(139) => 'i',
		chr(225).chr(187).chr(140) => 'O', chr(225).chr(187).chr(141) => 'o',
		chr(225).chr(187).chr(152) => 'O', chr(225).chr(187).chr(153) => 'o',
		chr(225).chr(187).chr(162) => 'O', chr(225).chr(187).chr(163) => 'o',
		chr(225).chr(187).chr(164) => 'U', chr(225).chr(187).chr(165) => 'u',
		chr(225).chr(187).chr(176) => 'U', chr(225).chr(187).chr(177) => 'u',
		chr(225).chr(187).chr(180) => 'Y', chr(225).chr(187).chr(181) => 'y',
		// Vowels with diacritic (Chinese, Hanyu Pinyin)
		chr(201).chr(145) => 'a',
		// macron
		chr(199).chr(149) => 'U', chr(199).chr(150) => 'u',
		// acute accent
		chr(199).chr(151) => 'U', chr(199).chr(152) => 'u',
		// caron
		chr(199).chr(141) => 'A', chr(199).chr(142) => 'a',
		chr(199).chr(143) => 'I', chr(199).chr(144) => 'i',
		chr(199).chr(145) => 'O', chr(199).chr(146) => 'o',
		chr(199).chr(147) => 'U', chr(199).chr(148) => 'u',
		chr(199).chr(153) => 'U', chr(199).chr(154) => 'u',
		// grave accent
		chr(199).chr(155) => 'U', chr(199).chr(156) => 'u',
		);

		// Used for locale-specific rules
		//$locale = get_locale();

		//if ( 'de_DE' == $locale ) {
			$chars[ chr(195).chr(132) ] = 'Ae';
			$chars[ chr(195).chr(164) ] = 'ae';
			$chars[ chr(195).chr(150) ] = 'Oe';
			$chars[ chr(195).chr(182) ] = 'oe';
			$chars[ chr(195).chr(156) ] = 'Ue';
			$chars[ chr(195).chr(188) ] = 'ue';
			$chars[ chr(195).chr(159) ] = 'ss';
		//}

		$string = strtr($string, $chars);
	} else {
		// Assume ISO-8859-1 if not UTF-8
		$chars['in'] = chr(128).chr(131).chr(138).chr(142).chr(154).chr(158)
			.chr(159).chr(162).chr(165).chr(181).chr(192).chr(193).chr(194)
			.chr(195).chr(196).chr(197).chr(199).chr(200).chr(201).chr(202)
			.chr(203).chr(204).chr(205).chr(206).chr(207).chr(209).chr(210)
			.chr(211).chr(212).chr(213).chr(214).chr(216).chr(217).chr(218)
			.chr(219).chr(220).chr(221).chr(224).chr(225).chr(226).chr(227)
			.chr(228).chr(229).chr(231).chr(232).chr(233).chr(234).chr(235)
			.chr(236).chr(237).chr(238).chr(239).chr(241).chr(242).chr(243)
			.chr(244).chr(245).chr(246).chr(248).chr(249).chr(250).chr(251)
			.chr(252).chr(253).chr(255);

		$chars['out'] = "EfSZszYcYuAAAAAACEEEEIIIINOOOOOOUUUUYaaaaaaceeeeiiiinoooooouuuuyy";

		$string = strtr($string, $chars['in'], $chars['out']);
		$double_chars['in'] = array(chr(140), chr(156), chr(198), chr(208), chr(222), chr(223), chr(230), chr(240), chr(254));
		$double_chars['out'] = array('OE', 'oe', 'AE', 'DH', 'TH', 'ss', 'ae', 'dh', 'th');
		$string = str_replace($double_chars['in'], $double_chars['out'], $string);
	}

	return $string;
}

/**
 * Checks to see if a string is utf8 encoded.
 *
 * NOTE: This function checks for 5-Byte sequences, UTF8
 *       has Bytes Sequences with a maximum length of 4.
 *
 * @author bmorel at ssi dot fr (modified)
 * @copyright WordPress
 * @since 1.2.1
 *
 * @param string $str The string to be checked
 * @return bool True if $str fits a UTF-8 model, false otherwise.
 */
function colp_wp_seems_utf8($str) {
	$length = strlen($str);
	for ($i=0; $i < $length; $i++) {
		$c = ord($str[$i]);
		if ($c < 0x80) $n = 0; # 0bbbbbbb
		elseif (($c & 0xE0) == 0xC0) $n=1; # 110bbbbb
		elseif (($c & 0xF0) == 0xE0) $n=2; # 1110bbbb
		elseif (($c & 0xF8) == 0xF0) $n=3; # 11110bbb
		elseif (($c & 0xFC) == 0xF8) $n=4; # 111110bb
		elseif (($c & 0xFE) == 0xFC) $n=5; # 1111110b
		else return false; # Does not match any model
		for ($j=0; $j<$n; $j++) { # n bytes matching 10bbbbbb follow ?
			if ((++$i == $length) || ((ord($str[$i]) & 0xC0) != 0x80))
				return false;
		}
	}
	return true;
}

?>