<?php

/**
 * Content of the latest posts
 *
 * @package ContentOfLatestPosts
 * @version 2.4
 * @author davidhs
 * @copyright 2010-2018 by davidhs
 * @license Creative Commons Attribution 3.0 Unported License https://creativecommons.org/licenses/by/3.0/
 */

if (!defined('SMF'))
	die('Hacking attempt...');

// Gets list of settings default.
function colpGetListSettingsDefault($start, $items_per_page, $sort)
{
	global $sourcedir;

	require_once ($sourcedir . '/Subs-ContentOfLatestPosts.php');

	$list = array();

	// $start, $items_per_page, $sort are not used: only exists one row.
	$colp_settings = colpGetSettings('default');
	if (!empty($colp_settings))
		$list[] = $colp_settings;

	return $list;
}

// Gets list of settings predefined.
function colpGetListSettingsPredefined($start, $items_per_page, $sort)
{
	global $sourcedir;

	if (!is_numeric($start) || empty($items_per_page) || empty($sort))
		return false;

	require_once ($sourcedir . '/Subs-ContentOfLatestPosts.php');

	$list = array();

	$colp_settings = colpGetSettings('predefined');

	if (!empty($colp_settings))
	{
		// Applies $sort.
		$sort_array = explode(' ', $sort);
		if (1 == count($sort_array))
			$sort_array[] = 'ASC';

		$flag_order = 'DESC' == strtoupper($sort_array[1]) ? SORT_DESC : SORT_ASC;
		$colp_settings = colp_array_column_sort($colp_settings, $sort_array[0], $flag_order, SORT_REGULAR);

		// Reindex.
		$colp_settings2 = $colp_settings;
		$colp_settings = array();
		foreach ($colp_settings2 as $row)
			$colp_settings[] = $row;

		// Paginate.
		$lim = min(count($colp_settings), $start + $items_per_page);
		for ($i = $start; $i < $lim; $i++)
			$list[] = $colp_settings[$i];
	}

	return $list;
}

// Gets size of list of settings predefined.
function colpGetListSettingsPredefinedSize()
{
	global $sourcedir;

	require_once ($sourcedir . '/Subs-ContentOfLatestPosts.php');

	$colp_settings = colpGetSettings('predefined');

	return count($colp_settings);
}

// Admin area settings (edit).
function colpSettingsEdit()
{
	global $txt, $context, $func, $sourcedir, $modSettings;

	require_once ($sourcedir . '/Subs-ContentOfLatestPosts.php');

	loadTemplate('ContentOfLatestPosts');

	// Sort out the context!
	$context['colp_type'] = isset($_GET['colp_type']) ? $_GET['colp_type'] : 'default';
	if ('default' == $context['colp_type'])
	{
		$context['id'] = isset($_GET['id']) ? 'default' : '';
		$context['settings_title'] = $context['id'] ? $txt['colp_edit_default_title'] : $txt['colp_add_default_title'];
		$context['params_url'] = '';
	}
	else
	{
		$context['id'] = isset($_GET['id']) ? (int) $_GET['id'] : 0;
		$context['settings_title'] = $context['id'] ? $txt['colp_edit_predefined_title'] : $txt['colp_add_predefined_title'];
		$start = isset($_GET['start']) ? (int) $_GET['start'] : 0;
		$sort = isset($_GET['sort']) ? $_GET['sort'] : 'id';
		$context['params_url'] = ';start=' . $start . ';sort=' . $sort . (isset($_GET['desc']) ? ';desc' : '');
	}
	$context['admin_tabs']['tabs']['colp']['is_selected'] = true;
	$context['sub_template'] = 'colp_settings_edit';

	if ($context['id'])
		$context['params'] = colpGetSettings($context['id']);

	// Setup the default values as needed.
	if (empty($context['params']))
		$context['params'] = colpGetSettings();

	// Others data.
	$context['params']['header'] = $func['htmlspecialchars']($context['params']['header'], ENT_QUOTES);
	$context['params']['not_content'] = $func['htmlspecialchars']($context['params']['not_content'], ENT_QUOTES);
	$context['params']['boards'] = explode(',', $context['params']['boards']);

	$format_array = colpSearch();
	$context['params']['type_array'] = array();
	foreach ($format_array as $type => $format)
		$context['params']['type_array'][$type] = $format['name'];

	loadJumpTo();
	$context['params']['all_boards'] = $context['jump_to'];

	$group_array = array('no', 'board', 'character');
	$context['params']['group_array'] = array();
	foreach ($group_array as $group)
		$context['params']['group_array'][$group] = $txt['colp_group_' . $group];

	$format_type_array = array('html', 'bbc', 'php');
	$context['params']['format_type_array'] = array();
	foreach ($format_type_array as $format_type)
		$context['params']['format_type_array'][$format_type] = $txt['colp_format_type_' . $format_type];

	$boards_link_array = array('all', 'parent', 'no');
	$context['params']['boards_link_array'] = array();
	foreach ($boards_link_array as $boards_link)
		$context['params']['boards_link_array'][$boards_link] = $txt['colp_boards_link_' . $boards_link];

	$context['params']['order_by_array'] = array(
		'date_desc' => $txt['colp_order_by_date_desc'],
		'subject_asc' => $txt['colp_order_by_subject_asc'],
	);

	$context['params']['unread_array'] = array(
		'no' => $txt[164],
		'new' => $txt['unread_topics_visit'],
		'all' => $txt['unread_topics_all'],
		'replies' => $txt['unread_replies'],
	);

	$context['params']['date_array'] = array(
		'create' => $txt['colp_date_create'],
		'modify' => $txt['colp_date_modify'],
	);

	$context['params']['triple_state'] = array(
		'all' => $txt[190],
		'yes' => $txt[163],
		'no' => $txt[164],
	);

	// Are we saving?
	if (isset($_POST['save']))
	{
		checkSession('get');

		// Validate inputs.
		$_POST['description'] = $func['htmlspecialchars']($_POST['description'], ENT_QUOTES);

		if ('character' == $_POST['group'])
		{
			$group_letters = array_map('trim', explode(',', $func['strtoupper']($_POST['group_letters'])));
			$group_letters = array_filter($group_letters, 'colpIsNotEmptyString');
			$group_letters = array_unique($group_letters);
			$group_letters = $func['htmlspecialchars'](implode(',', $group_letters), ENT_QUOTES);

			$group_prefix = array_map('trim', explode(',', $_POST['group_prefix']));
			$group_prefix = array_filter($group_prefix, 'colpIsNotEmptyString');
			$group_prefix = array_unique($group_prefix);
			$group_prefix = $func['htmlspecialchars'](implode(',', $group_prefix), ENT_QUOTES);
		}
		else
		{
			$group_letters = '';
			$group_prefix = '';
		}

		$show_boards = 'board' == $_POST['group'] || isset($_POST['show_boards']) ? 1 : 0;
		$show_icon = isset($_POST['show_icon']) ? 1 : 0;
		$show_subject = 'subject' == $_POST['type'] || isset($_POST['show_subject']) ? 1 : 0;
		$show_poster = isset($_POST['show_poster']) ? 1 : 0;
		$show_content = 'subject' != $_POST['type'] && (in_array($_POST['type'], array('all', 'post')) || isset($_POST['show_content'])) ? 1 : 0;
		$first_post_topic = isset($_POST['first_post_topic']) ? 1 : 0;
		$replies_topic = isset($_POST['replies_topic']) ? 1 : 0;

		$subject_prefix = array_map('trim', explode(',', $_POST['subject_prefix']));
		$subject_prefix = array_filter($subject_prefix, 'colpIsNotEmptyString');
		$subject_prefix = array_unique($subject_prefix);
		$subject_prefix = $func['htmlspecialchars'](implode(',', $subject_prefix), ENT_QUOTES);

		$no_subject_prefix = array_map('trim', explode(',', $_POST['no_subject_prefix']));
		$no_subject_prefix = array_filter($no_subject_prefix, 'colpIsNotEmptyString');
		$no_subject_prefix = array_unique($no_subject_prefix);
		$no_subject_prefix = $func['htmlspecialchars'](implode(',', $no_subject_prefix), ENT_QUOTES);

		$number_by_group = isset($_POST['number_by_group']) ? (int) $_POST['number_by_group'] : 0;
		$number_by_topic = isset($_POST['number_by_topic']) ? (int) $_POST['number_by_topic'] : 0;
		$age = isset($_POST['age']) ? (int) $_POST['age'] : 0;

		if (empty($_POST['boards']) || in_array('current', $_POST['boards']))
			$boards = 'current';
		else
			$boards = in_array('all', $_POST['boards']) ? 'all' : implode(',', $_POST['boards']);

		// Do the insertion/updates.
		$params = array_keys(colpGetSettings());

		if ('default' == $context['colp_type'])
			$id2 = 'default';
		elseif ($context['id'])
			$id2 = 'predefined_' . $context['id'];
		else // New predefined.
		{
			$id_new = 1;
			$ids = empty($modSettings['colp_predefined_ids']) ? array() : explode(',', $modSettings['colp_predefined_ids']);
			while (in_array($id_new, $ids))
				$id_new++;
			$id2 = 'predefined_' . $id_new;
		}

		$setArray = array();
		if (!$context['id'] && 'predefined' == $context['colp_type'])
		{
			$ids[] = $id_new;
			sort($ids);
			$setArray['colp_predefined_ids'] = implode(',', $ids);
		}
		foreach ($params as $param)
			$setArray['colp_' . $id2 . '_' . $param] = in_array($param, array('boards', 'group_letters', 'group_prefix', 'show_boards', 'show_icon', 'show_subject', 'show_poster', 'show_content', 'number_by_group', 'number_by_topic', 'age', 'first_post_topic', 'replies_topic', 'subject_prefix', 'no_subject_prefix')) ? $$param : $_POST[$param];
		colpUpdateSettings($setArray);
	}
	// Deleting?
	elseif (isset($_GET['delete']) && $context['id'])
	{
		checkSession('get');

		if ('default' == $context['colp_type'])
			$id2 = 'default';
		else // New predefined.
			$id2 = 'predefined_' . $context['id'];

		colpDeleteSettings('colp\\_' . $id2 . '\\_%');

		if ('predefined' == $context['colp_type'] && !empty($modSettings['colp_predefined_ids']))
		{
			$ids = explode(',', $modSettings['colp_predefined_ids']);
			$key = array_search($context['id'], $ids);
			if (is_numeric($key))
				unset($ids[$key]);

			$setArray = array();
			$setArray['colp_predefined_ids'] = implode(',', $ids);
			colpUpdateSettings($setArray);
		}
	}

	if (isset($_GET['delete']) || isset($_POST['save']))
	{
		checkSession('get');
		redirectexit('action=featuresettings;sa=colp' . $context['params_url']);
	}
}

// Admin area settings (show).
function colpSettingsShow()
{
	global $txt, $scripturl, $db_prefix, $context, $modSettings, $sourcedir, $settings;

	loadTemplate('ContentOfLatestPosts');
	loadTemplate('GenericList-ContentOfLatestPosts');

	$context['sub_template'] = 'colp_settings_show';
	$context['settings_title'] = $txt['colp'];

	$base_href = $scripturl . '?action=featuresettings;sa=colp';

	// Predefined list.
	$headers = array(
		'description' => array(
			'label' => $txt['colp_description'],
			'style' => 'text-align: left;',
		),
		'type' => array(
			'label' => $txt['colp_type'],
			'style' => 'width: 30%; text-align: left;',
		),
		'age' => array(
			'label' => $txt['colp_age'],
			'style' => 'width: 15%; text-align: center;',
		),
		'option_modify' => array(
			'style' => 'width: 10%;',
		),
		'option_delete' => array(
			'style' => 'width: 10%;',
		),
	);

	$num_columns = count($headers);

	$list = colpGetListSettingsDefault(0, 0, '');
	$rows = array();
	foreach ($list as $rowData)
	{
		$textKey = 'colp_type_' . $rowData['type'];
		$rows[] = array(
			'description' => array(
				'value' => nl2br($rowData['description']),
			),
			'type' => array(
				'value' => isset($txt[$textKey]) ? $txt[$textKey] : $textKey,
			),
			'age' => array(
				'value' => $rowData['age'] . ' ' . $txt[579],
				'style' => 'text-align: center;',
			),
			'option_modify' => array(
				'value' => '<a href="' . $scripturl . '?action=featuresettings;sa=colpedit;colp_type=default;id=' . $rowData['id'] . '">' . $txt[17] . '</a>',
				'style' => 'text-align: center;',
			),
			'option_delete' => array(
				'value' => '<a href="' . $scripturl . '?action=featuresettings;sa=colpedit;colp_type=default;delete=1;id=' . $rowData['id'] . ';sesc=' . $context['session_id'] . '" onclick="return confirm(\'' .$txt['colp_edit_delete_default_sure'] . '\');">' . $txt['smf138'] . '</a>',
				'style' => 'text-align: center;',
			),
		);
	}

	$context['colp_settings_show_default'] = array(
		'title' => $txt['colp_default_param'],
		'no_items_label' => $txt['colp_none_default'] . '<br /><input type="submit" name="new" value="' . $txt['colp_make_new_default'] . '" />',
		'num_columns' => $num_columns,
		'headers' => $headers,
		'rows' => $rows,
		'form' => array(
			'href' => $scripturl . '?action=featuresettings;sa=colpedit;colp_type=default',
			'name' => 'colpDefault',
			'hidden_fields' => array(
				'sc' => $context['session_id'],
			),
		),
	);

	// Predefined list.
	$get_count = colpGetListSettingsPredefinedSize();
	$items_per_page = 25;

	$headers = array(
		'id' => array(
			'label' => $txt['colp_id'],
			'style' => 'width: 5%; text-align: center;',
			'sort' => array(
				'default' => 'id',
				'reverse' => 'id DESC',
			),
		),
		'description' => array(
			'label' => $txt['colp_description'],
			'style' => 'text-align: left;',
			'sort' => array(
				'default' => 'description',
				'reverse' => 'description DESC',
			),
		),
		'type' => array(
			'label' => $txt['colp_type'],
			'style' => 'width: 30%; text-align: left;',
			'sort' => array(
				'default' => 'type',
				'reverse' => 'type DESC',
			),
		),
		'age' => array(
			'label' => $txt['colp_age'],
			'style' => 'width: 15%; text-align: center;',
			'sort' => array(
				'default' => 'age',
				'reverse' => 'age DESC',
			),
		),
		'option_modify' => array(
			'style' => 'width: 10%;',
		),
		'option_delete' => array(
			'style' => 'width: 10%;',
		),
	);

	$sort = isset($_REQUEST['sort']) && isset($headers[$_REQUEST['sort']]) && isset($headers[$_REQUEST['sort']]['sort']) ? $_REQUEST['sort'] : 'id';
	$sort_order = $headers[$sort]['sort'][isset($_REQUEST['desc']) ? 'reverse' : 'default'];
	$page_index = constructPageIndex($base_href . ';sort=' . $sort . (isset($_REQUEST['desc']) ? ';desc' : ''), $_REQUEST['start'], $get_count, $items_per_page);
	$start = $_REQUEST['start'];
	$params_url = ';start=' . $start . ';sort=' . $sort . (isset($_REQUEST['desc']) ? ';desc' : '');

	foreach ($headers as $col => $col_header)
	{
		if (isset($headers[$col]['sort']))
		{
			$headers[$col]['href'] = $base_href . ';sort=' . $col;
			if (!isset($_REQUEST['desc']) && $col == $sort)
				$headers[$col]['href'] .= ';desc';
			if ($col == $sort)
				$headers[$col]['sort_image'] = !isset($_REQUEST['desc']) ? 'down' : 'up';
			$headers[$col]['selected'] = $col == $sort;
		}
	}
	$num_columns = count($headers);

	$list = colpGetListSettingsPredefined($start, $items_per_page, $sort_order);
	$rows = array();
	foreach ($list as $rowData)
	{
		$textKey = 'colp_type_' . $rowData['type'];
		$rows[] = array(
			'id' => array(
				'value' => $rowData['id'],
				'style' => 'text-align: center;',
			),
			'description' => array(
				'value' => nl2br($rowData['description']),
			),
			'type' => array(
				'value' => isset($txt[$textKey]) ? $txt[$textKey] : $textKey,
			),
			'age' => array(
				'value' => $rowData['age'] . ' ' . $txt[579],
				'style' => 'text-align: center;',
			),
			'option_modify' => array(
				'value' => '<a href="' . $scripturl . '?action=featuresettings;sa=colpedit;colp_type=predefined;id=' . $rowData['id'] . $params_url . '">' . $txt[17] . '</a>',
				'style' => 'text-align: center;',
			),
			'option_delete' => array(
				'value' => '<a href="' . $scripturl . '?action=featuresettings;sa=colpedit;colp_type=predefined;delete=1;id=' . $rowData['id'] . $params_url . ';sesc=' . $context['session_id'] . '" onclick="return confirm(\'' .$txt['colp_edit_delete_predefined_sure'] . '\');">' . $txt['smf138'] . '</a>',
				'style' => 'text-align: center;',
			),
		);
	}

	$context['colp_settings_show_predefined'] = array(
		'title' => $txt['colp_predefined_list'],
		'no_items_label' => $txt['colp_none_predefined'],
		'items_per_page' => $items_per_page,
		'page_index' => $page_index,
		'num_columns' => $num_columns,
		'headers' => $headers,
		'rows' => $rows,
		'form' => array(
			'href' => $scripturl . '?action=featuresettings;sa=colpedit;colp_type=predefined' . $params_url,
			'name' => 'colpPredefined',
			'hidden_fields' => array(
				'sc' => $context['session_id'],
			),
		),
		'additional_rows' => array(
			'below_table_data' => array(
				array(
					'value' => '<input type="submit" name="new" value="' . $txt['colp_make_new_predefined'] . '" />',
					'style' => 'text-align: right;',
				),
			),
		),
	);
}

// Updates settings.
function colpUpdateSettings($setArray)
{
	global $db_prefix;

	if (empty($setArray))
		return false;

	$replaceArray = array();
	foreach ($setArray as $variable => $value)
		$replaceArray[] = "(SUBSTRING('$variable', 1, 255), SUBSTRING('$value', 1, 65534))";

	db_query("
		REPLACE INTO {$db_prefix}settings
			(variable, value)
		VALUES " . implode(',
			', $replaceArray), __FILE__, __LINE__);

	// Kill the cache - it needs redoing now, but we won't bother ourselves with that here.
	cache_put_data('modSettings', null, 90);
}

// Deletes settings.
function colpDeleteSettings($filter)
{
	global $db_prefix;

	if (empty($filter))
		return false;

	db_query("
		DELETE FROM {$db_prefix}settings
		WHERE variable LIKE '$filter'", __FILE__, __LINE__);

	// Kill the cache - it needs redoing now, but we won't bother ourselves with that here.
	cache_put_data('modSettings', null, 90);
}

/**
 * array_column_sort
 *
 * function to sort an "arrow of rows" by its columns
 * exracts the columns to be sorted and then
 * uses eval to flexibly apply the standard
 * array_multisort function
 *
 * uses a temporary copy of the array whith "_" prefixed to the keys
 * this makes sure that array_multisort is working with an associative
 * array with string type keys, which in turn ensures that the keys
 * will be preserved.
 *
 * TODO: find a way of modifying the keys of $array directly, without using
 * a copy of the array.
 *
 * flexible syntax:
 * $new_array = array_column_sort($array [, 'col1' [, SORT_FLAG [, SORT_FLAG]]]...);
 *
 * original code credited to Ichier (www.ichier.de) here:
 * http://uk.php.net/manual/en/function.array-multisort.php
 *
 * prefixing array indeces with "_" idea credit to steve at mg-rover dot org, also here:
 * http://uk.php.net/manual/en/function.array-multisort.php
 *
 */
function colp_array_column_sort() {
	$args = func_get_args();
	$array = array_shift($args);

	// make a temporary copy of array for which will fix the
	// keys to be strings, so that array_multisort() doesn't
	// destroy them
	$array_mod = array();
	foreach ($array as $key => $value) {
		$array_mod['_' . $key] = $value;
	}

	$i = 0;
	$multi_sort_line = "return array_multisort(";
	foreach ($args as $arg) {
		$i++;
		if (is_string($arg)) {
			foreach ($array_mod as $row_key => $row) {
				$sort_array[$i][] = $row[$arg];
			}
		} else {
			$sort_array[$i] = $arg;
		}
		$multi_sort_line .= "\$sort_array[" . $i . "], ";
	}
	$multi_sort_line .= "\$array_mod);";

	eval($multi_sort_line);

	// now copy $array_mod back into $array, stripping off the "_"
	// that we added earlier.
	$array = array();
	foreach ($array_mod as $key => $value) {
		$array[substr($key, 1)] = $value;
	}
	return $array;
}

?>