<?php

/**
 * Content of the latest posts
 *
 * @package ContentOfLatestPosts
 * @version 2.4
 * @author davidhs
 * @copyright 2010-2018 by davidhs
 * @license Creative Commons Attribution 3.0 Unported License https://creativecommons.org/licenses/by/3.0/
 */

// Returns code with content latest.
function template_colp_get($group, $board_array, $char_array, $format_gr, $post_array, $not_content)
{
	$text = '<div class="contentlatest">';
	switch ($group)
	{
		case 'no':
		{
			if (!empty($post_array))
			{
				$text .=
					$format_gr['format_gr_begin'] .
					template_colp_get_post($post_array, $board_array) .
					$format_gr['format_gr_end'];
			}
			else
				$text .= $not_content;
			break;
		}
		case 'board':
		{
			if (!empty($post_array))
			{
				foreach ($board_array as $id_board => $board_array2)
				{
					$text .=
						template_colp_get_boards($board_array2) .
						$format_gr[$id_board]['format_gr_begin'] .
						template_colp_get_post($post_array[$id_board]) .
						$format_gr[$id_board]['format_gr_end'];
				}
			}
			else
				$text .= $not_content;
			break;
		}
		case 'character':
		{
			$text .= template_colp_get_chars($char_array);
			if (!empty($post_array))
			{
				foreach ($char_array as $key => $char)
				{
					if (isset($post_array[$key]))
					{
						$text .=
							template_colp_get_chars($char) .
							$format_gr[$key]['format_gr_begin'] .
							template_colp_get_post($post_array[$key], $board_array) .
							$format_gr[$key]['format_gr_end'];
					}
				}
			}
			else
				$text .= $not_content;
			break;
		}
	}
	$text .= '</div>';

	return $text;
}

// Returns code with navigation tree of boards.
function template_colp_get_boards($board_array)
{
	$dim_i = count($board_array);

	$text = '<div class="nav" style="font-size: smaller; margin-bottom: 2ex; margin-top: 2ex;">';

	// Each item has a URL and name.
	foreach ($board_array as $i => $board)
	{
		// Show the link, including a URL if it should have one.
		$text .= '<b>' . (isset($board['url']) ? '<a href="' . $board['url'] . '" class="nav"><span>' . $board['name'] . '</span></a>' : '<span>' . $board['name'] . '</span>') . '</b>';

		// Don't show a separator for the last one.
		if ($i != ($dim_i - 1))
			$text .= '&nbsp;&gt;&nbsp;';
	}

	$text .= '</div>';

	return $text;
}

// Returns code with navigation of chars.
function template_colp_get_chars($char)
{
	static $index_key = 0;
	global $txt;

	$index = !isset($char['text']);

	$text = '<div class="colp_index' . (!$index ? '_char' : '') . '"><div class="nav" style="font-size: smaller; margin-bottom: 2ex; margin-top: 2ex;">';

	if ($index)
	{
		$index_key++;
		$i = 0;
		$dim_i = count($char);
		foreach ($char as $key => $char2)
		{
			if (0 == $i)
				$text .= '<a name="colp_index_' . $index_key . '"></a>';

			// Show the link, including a URL if it should have one.
			$text .= '<b>' . (isset($char2['url']) ? '<a href="' . $char2['url'] . '_' . $index_key . '" class="nav"><span>' . $char2['text'] . '</span></a>' : '<span>' . $char2['text'] . '</span>') . '</b>';

			// Don't show a separator for the last one.
			if ($i != ($dim_i - 1))
				$text .= ' | ';

			$i++;
		}
	}
	else
	{
		$text .=
			'<b><a name="' . $char['name'] . '_' . $index_key . '" class="nav"></a><span>' . $char['text'] . '</span></b> | ' .
			'<b><a href="#colp_index_' . $index_key . '" class="nav"><span>' . $txt['colp_go_to_index'] . '</span></a></b>';
	}

	$text .= '</div></div>';

	return $text;
}

// Returns code with content latest of posts.
function template_colp_get_post($post_array, $board_array = array())
{
	global $txt;

	$text = '';
	foreach ($post_array as $row)
	{
		$quoteheader = '';
		if (!empty($board_array) || isset($row['icon']) || isset($row['subject']) || isset($row['time']))
		{
			if (!empty($board_array))
				$quoteheader .= template_colp_get_boards($board_array[$row['ID_BOARD']]);
			if (isset($row['icon']))
				$quoteheader .= '<img src="' . $row['icon_url'] . '" alt="" border="0" style="float: left; margin-right: 1em;" />';
			if (isset($row['subject']))
				$quoteheader .= '<a href="' . $row['href'] . '">' . $row['subject'] . '</a><br />';
			if (isset($row['time']))
			{
				if ($row['ID_MEMBER'])
					$by_member = $txt[525] . ' <a href="' . $row['profile_url'] . '">' . $row['memberName'] . '</a> ';
				elseif ($row['posterName'] || is_numeric($row['posterName']))
					$by_member = $txt[525] . ' ' . $row['posterName'] . ' ';
				else
					$by_member = '';

				$quoteheader .= $by_member . $txt[176] . ' ' . $row['time'];
			}
		}

		if (!empty($quoteheader))
			$text .= '<div class="quoteheader">' . $quoteheader . '</div>';
		if (isset($row['content']))
			$text .= '<div class="quote">' . $row['content'] . '</div>';

		if (isset($row['format_content']))
			$text .= $row['format_content'];
	}

	return $text;
}

// Returns code with content latest of attachment type.
function template_colp_get_type_attachment($attach_array)
{
	global $settings, $txt;
	static $nr = 1;

	$icon_url = $settings['images_url'] . '/icons/clip.gif';

	$text = '';
	foreach ($attach_array as $row)
	{
		if (!empty($text))
			$text .= '<br />';

		if ($row['is_image'])
		{
			if ($row['thumbnail']['has_thumb'])
			{
				$nr2 = (int) $nr . $row['id'];
				$trans = array(
					$row['id'] => $nr2,
				);
				$javascript = strtr($row['thumbnail']['javascript'], $trans);

				$text .= '<a href="' . $row['href'] . ';image" id="link_' . $nr2 . '" onclick="' . $javascript . '"><img src="' . $row['thumbnail']['href'] . '" alt="" id="thumb_' . $nr2 . '" border="0" /></a><br />';
				$nr++;
			}
			else
				$text .= '<img src="' . $row['href'] . ';image" alt="" width="' . $row['width'] . '" height="' . $row['height'] . '" border="0" /><br />';
		}
		$text .= '<a href="' . $row['href'] . '"><img src="' . $icon_url . '" align="middle" alt="*" border="0" />&nbsp;' . $row['name'] . '</a>' .
			' (' . $row['size'] .
			($row['is_image'] ? ', ' . $row['real_width'] . 'x' . $row['real_height'] . ' - ' . $txt['attach_viewed'] : ' - ' . $txt['attach_downloaded']) .
			' ' . $row['downloads'] . ' ' . $txt['attach_times'] . '.)';
	}
	if (!empty($text))
		$text = '<div class="smalltext"><hr width="100%" size="1" class="hrcolor" />' . $text . '</div>';

	return $text;
}

// Returns code with content latest of link type.
function template_colp_get_type_link($link_array)
{
	return implode("\n", $link_array);
}

// Returns code with content latest of elink type.
function template_colp_get_type_elink($elink_array)
{
	$text = '';
	foreach ($elink_array as $elink => $file)
	{
		if (!empty($text))
			$text .= "\n";
		$text .= '&lt;a href=&quot;' . $elink . '&quot;&gt;' . urldecode($file) . '&lt;/a&gt;';
	}

	return $text;
}

// Returns code with content latest of image type.
function template_colp_get_type_image($img_array)
{
	return empty($img_array) ? '' : '[center]' . implode("\n\n", $img_array) . '[/center]';
}

// Template for admin area settings (edit).
function template_colp_settings_edit()
{
	global $txt, $scripturl, $context, $settings;

	echo '
	<form action="', $scripturl, '?action=featuresettings;sa=colpedit;colp_type=', $context['colp_type'], ';id=', $context['id'], $context['params_url'], ';sesc=', $context['session_id'], '" method="post" accept-charset="', $context['character_set'], '">
		<table width="80%" border="0" cellspacing="0" cellpadding="0" class="tborder" align="center">
			<tr><td>
				<table border="0" cellspacing="0" cellpadding="4" width="100%">
					<tr class="titlebg">
						<td colspan="3">', $context['settings_title'], '</td>
					</tr>
					<tr class="windowbg2">
						<td colspan="3">
							<fieldset>
								<legend>', $txt['colp_settings_display'], '</legend>
								<table border="0" cellspacing="0" cellpadding="4" width="100%">
									<tr class="windowbg2">
										<td class="windowbg2"></td>
										<td valign="top">
											<label for="description">', $txt['colp_description'], '</label>
										</td>
										<td class="windowbg2" width="50%">
											<textarea name="description" id="description" rows="2" cols="30">', $context['params']['description'], '</textarea>
										</td>
									</tr>
									<tr class="windowbg2">
										<td class="windowbg2" valign="top" width="16"><a href="', $scripturl, '?action=helpadmin;help=colp_header" onclick="return reqWin(this.href);" class="help"><img src="', $settings['images_url'], '/helptopics.gif" alt="', $txt[119], '" border="0" align="top" /></a></td>
										<td valign="top">
											<label for="colp_header">', $txt['colp_header'], '</label><br />
											<span class="smalltext">', $txt['colp_header_desc'], '</span>
										</td>
										<td class="windowbg2" width="50%">
											<textarea name="header" id="colp_header" rows="4" cols="30" style="min-width: 90%;">', $context['params']['header'], '</textarea>
										</td>
									</tr>
									<tr class="windowbg2">
										<td class="windowbg2"></td>
										<td valign="top">
											<label for="not_content">', $txt['colp_not_content'], '</label><br />
											<span class="smalltext">', $txt['colp_not_content_desc'], '</span>
										</td>
										<td class="windowbg2" width="50%">
											<input type="text" name="not_content" id="not_content" value="', $context['params']['not_content'], '" size="30" />
										</td>
									</tr>
									<tr class="windowbg2">
										<td class="windowbg2"></td>
										<td valign="top">
											<label for="type">', $txt['colp_type'], '</label>
										</td>
										<td class="windowbg2" width="50%">
											<select name="type" id="type">';

	foreach ($context['params']['type_array'] as $k => $v)
		echo '
												<option value="', $k, '"', $context['params']['type'] == $k ? ' selected="selected"' : '', '>', $v, '</option>';

	echo '
											</select>
										</td>
									</tr>
									<tr class="windowbg2">
										<td class="windowbg2"></td>
										<td valign="top">
											<label for="group">', $txt['colp_group'], '</label>
										</td>
										<td class="windowbg2" width="50%">
											<select name="group" id="group">';

	foreach ($context['params']['group_array'] as $k => $v)
		echo '
												<option value="', $k, '"', $context['params']['group'] == $k ? ' selected="selected"' : '', '>', $v, '</option>';

	echo '
											</select>
										</td>
									</tr>
									<tr class="windowbg2" id="group_letters_tr">
										<td class="windowbg2"></td>
										<td valign="top">
											<label for="group_letters">', $txt['colp_group_letters'], '</label><br />
											<span class="smalltext">', $txt['colp_group_letters_desc'], '</span>
										</td>
										<td class="windowbg2" width="50%">
											<input type="text" name="group_letters" id="group_letters" value="', $context['params']['group_letters'], '" size="30" />
										</td>
									</tr>
									<tr class="windowbg2" id="group_prefix_tr">
										<td class="windowbg2"></td>
										<td valign="top">
											<label for="group_prefix">', $txt['colp_group_prefix'], '</label><br />
											<span class="smalltext">', $txt['colp_group_prefix_desc'], '</span>
										</td>
										<td class="windowbg2" width="50%">
											<input type="text" name="group_prefix" id="group_prefix" value="', $context['params']['group_prefix'], '" size="30" />
										</td>
									</tr>
									<tr class="windowbg2" id="show_boards_tr">
										<td class="windowbg2"></td>
										<td valign="top">
											<label for="show_boards">', $txt['colp_show_boards'], '</label>
										</td>
										<td class="windowbg2" width="50%">
											<input type="checkbox" name="show_boards" id="show_boards" value="1"', $context['params']['show_boards'] ? ' checked="checked"' : '', ' class="check" />
										</td>
									</tr>
									<tr class="windowbg2">
										<td class="windowbg2"></td>
										<td valign="top">
											<label for="show_icon">', $txt['colp_show_icon'], '</label>
										</td>
										<td class="windowbg2" width="50%">
											<input type="checkbox" name="show_icon" id="show_icon" value="1"', $context['params']['show_icon'] ? ' checked="checked"' : '', ' class="check" />
										</td>
									</tr>
									<tr class="windowbg2" id="show_subject_tr">
										<td class="windowbg2"></td>
										<td valign="top">
											<label for="show_subject">', $txt['colp_show_subject'], '</label>
										</td>
										<td class="windowbg2" width="50%">
											<input type="checkbox" name="show_subject" id="show_subject" value="1"', $context['params']['show_subject'] ? ' checked="checked"' : '', ' class="check" />
										</td>
									</tr>
									<tr class="windowbg2">
										<td class="windowbg2"></td>
										<td valign="top">
											<label for="show_poster">', $txt['colp_show_poster'], '</label>
										</td>
										<td class="windowbg2" width="50%">
											<input type="checkbox" name="show_poster" id="show_poster" value="1"', $context['params']['show_poster'] ? ' checked="checked"' : '', ' class="check" />
										</td>
									</tr>
									<tr class="windowbg2" id="show_content_tr">
										<td class="windowbg2"></td>
										<td valign="top">
											<label for="show_content">', $txt['colp_show_content'], '</label>
										</td>
										<td class="windowbg2" width="50%">
											<input type="checkbox" name="show_content" id="show_content" value="1"', $context['params']['show_content'] ? ' checked="checked"' : '', ' class="check" />
										</td>
									</tr>
									<tr class="windowbg2">
										<td class="windowbg2" valign="top" width="16"><a href="', $scripturl, '?action=helpadmin;help=colp_format" onclick="return reqWin(this.href);" class="help"><img src="', $settings['images_url'], '/helptopics.gif" alt="', $txt[119], '" border="0" align="top" /></a></td>
										<td valign="top">
											', $txt['colp_format'], '<br />
											<span class="smalltext">', $txt['colp_format_desc'], '</span>
										</td>
										<td class="windowbg2" width="50%">
											<label for="format_type">', $txt['colp_format_type'], '</label>
											<select name="format_type" id="format_type">';

	foreach ($context['params']['format_type_array'] as $k => $v)
		echo '
												<option value="', $k, '"', $context['params']['format_type'] == $k ? ' selected="selected"' : '', '>', $v, '</option>';

	echo '
											</select><br />
											<label for="format_gr_begin">', $txt['colp_format_gr_begin'], '</label>
											<textarea name="format_gr_begin" id="format_gr_begin" rows="4" cols="30" style="min-width: 90%;">', $context['params']['format_gr_begin'], '</textarea><br />
											<label for="format_content">', $txt['colp_format_content'], '</label>
											<textarea name="format_content" id="format_content" rows="4" cols="30" style="min-width: 90%;">', $context['params']['format_content'], '</textarea><br />
											<label for="format_gr_end">', $txt['colp_format_gr_end'], '</label>
											<textarea name="format_gr_end" id="format_gr_end" rows="4" cols="30" style="min-width: 90%;">', $context['params']['format_gr_end'], '</textarea>
										</td>
									</tr>
									<tr class="windowbg2">
										<td class="windowbg2"></td>
										<td valign="top">
											<label for="boards_link">', $txt['colp_boards_link'],'</label>
										</td>
										<td class="windowbg2" width="50%">
											<select name="boards_link" id="boards_link">';

	foreach ($context['params']['boards_link_array'] as $k => $v)
		echo '
												<option value="', $k, '"', $context['params']['boards_link'] == $k ? ' selected="selected"' : '', '>', $v, '</option>';

	echo '
											</select>
										</td>
									</tr>
								</table>
							</fieldset>
							<fieldset>
								<legend>', $txt['colp_settings_advanced'], '</legend>
								<table border="0" cellspacing="0" cellpadding="4" width="100%">
									<tr class="windowbg2">
										<td class="windowbg2"></td>
										<td valign="top">
											<label for="boards">', $txt['colp_boards'], '</label>
										</td>
										<td class="windowbg2" width="50%">
											<select name="boards[]" id="boards" size="10" multiple="multiple">
												<option value="current"', empty($context['params']['boards']) || in_array('current', $context['params']['boards']) ? ' selected="selected"' : '', '>', $txt['colp_boards_current'], '</option>
												<option value="all"', in_array('all', $context['params']['boards']) ? ' selected="selected"' : '', '>', $txt[190], '</option>';

	foreach ($context['params']['all_boards'] as $category)
	{
		echo '
												<option value="" disabled="disabled">-----------------------------</option>
												<option value="" disabled="disabled">', $category['name'], '</option>
												<option value="" disabled="disabled">-----------------------------</option>';

		foreach ($category['boards'] as $board)
			echo '
												<option value="', $board['id'], '"', in_array($board['id'], $context['params']['boards']) ? ' selected="selected"' : '', '> ', str_repeat('==', $board['child_level']), '=> ', $board['name'], '</option>';
	}

	echo '
											</select>
										</td>
									</tr>
									<tr class="windowbg2">
										<td class="windowbg2"></td>
										<td valign="top">
											<label for="child_boards">', $txt['colp_child_boards'], '</label>
										</td>
										<td class="windowbg2" width="50%">
											<select name="child_boards" id="child_boards">
												<option value=""', !is_numeric($context['params']['child_boards']) ? ' selected="selected"' : '', '>', $txt[190], '</option>
												<option value="0"', is_numeric($context['params']['child_boards']) && empty($context['params']['child_boards']) ? ' selected="selected"' : '', '>', $txt[164], '</option>';

	for ($k = 1; $k < 256; $k++)
		echo '
												<option value="', $k, '"', $k == $context['params']['child_boards'] ? ' selected="selected"' : '', '>', sprintf($txt['colp_child_boards_until'], $k), '</option>';

	echo '
											</select>
										</td>
									</tr>
									<tr class="windowbg2">
										<td class="windowbg2"></td>
										<td valign="top">
											<label for="order_by">', $txt['colp_order_by'],'</label>
										</td>
										<td class="windowbg2" width="50%">
											<select name="order_by" id="order_by">';

	foreach ($context['params']['order_by_array'] as $k => $v)
		echo '
												<option value="', $k, '"', $context['params']['order_by'] == $k ? ' selected="selected"' : '', '>', $v, '</option>';

	echo '
											</select>
										</td>
									</tr>
									<tr class="windowbg2">
										<td class="windowbg2"></td>
										<td valign="top">
											<label for="number_by_group">', $txt['colp_number_by_group'], '</label><br />
											<span class="smalltext">', $txt['colp_number_by_group_desc'], '</span>
										</td>
										<td class="windowbg2" width="50%">
											<input type="text" name="number_by_group" id="number_by_group" value="', $context['params']['number_by_group'], '" size="5" />
										</td>
									</tr>
									<tr class="windowbg2">
										<td class="windowbg2"></td>
										<td valign="top">
											<label for="number_by_topic">', $txt['colp_number_by_topic'], '</label><br />
											<span class="smalltext">', $txt['colp_number_by_topic_desc'], '</span>
										</td>
										<td class="windowbg2" width="50%">
											<input type="text" name="number_by_topic" id="number_by_topic" value="', $context['params']['number_by_topic'], '" size="5" />
										</td>
									</tr>
									<tr class="windowbg2">
										<td class="windowbg2"></td>
										<td valign="top">
											<label for="age">', $txt['colp_age'], '</label>
										</td>
										<td class="windowbg2" width="50%">
											<input type="text" name="age" id="age" value="', $context['params']['age'], '" size="5" />
											', $txt[579], '
										</td>
									</tr>
									<tr class="windowbg2">
										<td class="windowbg2"></td>
										<td valign="top">
											<label for="unread">', $txt['colp_unread'], '</label>
										</td>
										<td class="windowbg2" width="50%">
											<select name="unread" id="unread">';

	foreach ($context['params']['unread_array'] as $k => $v)
		echo '
												<option value="', $k, '"', $context['params']['unread'] == $k ? ' selected="selected"' : '', '>', $v, '</option>';

	echo '
											</select>
										</td>
									</tr>
									<tr class="windowbg2">
										<td class="windowbg2"></td>
										<td valign="top">
											<label for="date">', $txt['colp_date'], '</label>
										</td>
										<td class="windowbg2" width="50%">
											<select name="date" id="date">';

	foreach ($context['params']['date_array'] as $k => $v)
		echo '
												<option value="', $k, '"', $context['params']['date'] == $k ? ' selected="selected"' : '', '>', $v, '</option>';

	echo '
											</select>
										</td>
									</tr>
									<tr class="windowbg2">
										<td class="windowbg2"></td>
										<td valign="top">
											<label for="sticky">', $txt['colp_sticky'], '</label>
										</td>
										<td class="windowbg2" width="50%">
											<select name="sticky" id="sticky">';

	foreach ($context['params']['triple_state'] as $k => $v)
		echo '
												<option value="', $k, '"', $context['params']['sticky'] == $k ? ' selected="selected"' : '', '>', $v, '</option>';

	echo '
											</select>
										</td>
									</tr>
									<tr class="windowbg2">
										<td class="windowbg2"></td>
										<td valign="top">
											<label for="locked">', $txt['colp_locked'], '</label>
										</td>
										<td class="windowbg2" width="50%">
											<select name="locked" id="locked">';

	foreach ($context['params']['triple_state'] as $k => $v)
		echo '
												<option value="', $k, '"', $context['params']['locked'] == $k ? ' selected="selected"' : '', '>', $v, '</option>';

	echo '
											</select>
										</td>
									</tr>
									<tr class="windowbg2">
										<td class="windowbg2"></td>
										<td valign="top">
											<label for="first_post_topic">', $txt['colp_first_post_topic'], '</label>
										</td>
										<td class="windowbg2" width="50%">
											<input type="checkbox" name="first_post_topic" id="first_post_topic" value="1"', $context['params']['first_post_topic'] ? ' checked="checked"' : '', ' class="check" />
										</td>
									</tr>
									<tr class="windowbg2">
										<td class="windowbg2"></td>
										<td valign="top">
											<label for="replies_topic">', $txt['colp_replies_topic'], '</label>
										</td>
										<td class="windowbg2" width="50%">
											<input type="checkbox" name="replies_topic" id="replies_topic" value="1"', $context['params']['replies_topic'] ? ' checked="checked"' : '', ' class="check" />
										</td>
									</tr>
									<tr class="windowbg2">
										<td class="windowbg2"></td>
										<td valign="top">
											<label for="subject_prefix">', $txt['colp_subject_prefix'], '</label><br />
											<span class="smalltext">', $txt['colp_subject_prefix_desc'], '</span>
										</td>
										<td class="windowbg2" width="50%">
											<input type="text" name="subject_prefix" id="subject_prefix" value="', $context['params']['subject_prefix'], '" size="30" />
										</td>
									</tr>
									<tr class="windowbg2">
										<td class="windowbg2"></td>
										<td valign="top">
											<label for="no_subject_prefix">', $txt['colp_no_subject_prefix'], '</label><br />
											<span class="smalltext">', $txt['colp_no_subject_prefix_desc'], '</span>
										</td>
										<td class="windowbg2" width="50%">
											<input type="text" name="no_subject_prefix" id="no_subject_prefix" value="', $context['params']['no_subject_prefix'], '" size="30" />
										</td>
									</tr>
								</table>
							</fieldset>
						</td>
					</tr><tr>
						<td class="windowbg2" colspan="3" align="center" valign="middle"><input type="submit" name="save" value="', $txt[10], '" accesskey="s" /></td>
					</tr>
				</table>
			</td></tr>
		</table>
	</form>
	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		function updateInputBoxes()
		{
			var type = document.getElementById("type").value;
			var group = document.getElementById("group").value;

			document.getElementById("group_letters_tr").style.display = "character" == group ? "" : "none";
			document.getElementById("group_prefix_tr").style.display = "character" == group ? "" : "none";
			document.getElementById("show_boards_tr").style.display = "board" != group ? "" : "none";

			document.getElementById("show_subject_tr").style.display = "subject" != type ? "" : "none";
			document.getElementById("show_content_tr").style.display = "all" != type && "post" != type && "subject" != type ? "" : "none";
		}

		document.getElementById("type").onchange = function (event)
		{
			updateInputBoxes();
		}

		document.getElementById("group").onchange = function (event)
		{
			updateInputBoxes();
		}

		updateInputBoxes();
	// ]]></script>';
}

// Template for admin area settings (show).
function template_colp_settings_show()
{
	global $txt, $scripturl, $context, $settings;

	echo '
	<table width="100%" border="0" cellspacing="0" cellpadding="0" class="tborder" align="center">
		<tr><td>
			<table border="0" cellspacing="0" cellpadding="4" width="100%">
				<tr class="titlebg">
					<td valign="top" width="16"><a href="', $scripturl, '?action=helpadmin;help=colp" onclick="return reqWin(this.href);" class="help"><img src="', $settings['images_url'], '/helptopics.gif" alt="', $txt[119], '" border="0" align="top" /></a></td>
					<td>', $context['settings_title'], '</td>
				</tr>
				<tr class="windowbg2">
					<td colspan="2" class="windowbg2">';

	template_colp_show_list('colp_settings_show_default');

	echo '
						<br />';

	template_colp_show_list('colp_settings_show_predefined');

	echo '
					</td>
				</tr>
			</table>
		</td></tr>
	</table>';
}

?>