<?php

/**
 * Content of the latest posts
 *
 * @package ContentOfLatestPosts
 * @version 2.4
 * @author davidhs
 * @copyright 2010-2018 by davidhs
 * @license Creative Commons Attribution 3.0 Unported License https://creativecommons.org/licenses/by/3.0/
 */

// Shows list.
function template_colp_show_list($list_id = null)
{
	global $context, $settings, $txt;

	// Get a shortcut to the current list.
	$list_id = $list_id === null ? $context['default_list'] : $list_id;
	$cur_list = &$context[$list_id];
	$col_count = count($cur_list['headers']);

	// These are the main tabs that is used all around the template.
	if (!empty($settings['use_tabs']) && isset($cur_list['list_menu'], $cur_list['list_menu']['show_on']) && ($cur_list['list_menu']['show_on'] == 'both' || $cur_list['list_menu']['show_on'] == 'top'))
		template_colp_create_list_menu($cur_list['list_menu'], 'top');

	if (isset($cur_list['form']))
		echo '
	<form action="', $cur_list['form']['href'], '" method="post"', empty($cur_list['form']['name']) ? '' : ' name="' . $cur_list['form']['name'] . '" id="' . $cur_list['form']['name'] . '"', ' accept-charset="', $context['character_set'], '">';

	echo '
		<table border="0" cellspacing="1" cellpadding="4" align="center" width="100%" class="bordercolor">';

	// Show the title of the table (if any).
	if (!empty($cur_list['title']))
	{
		echo '
			<tr class="catbg">
				<td align="left" colspan="', $cur_list['num_columns'], '">
					', $cur_list['title'], '
				</td>
			</tr>';
	}

	// This is for the old style menu with the arrows "> Test | Test 1".
	if (empty($settings['use_tabs']) && isset($cur_list['list_menu'], $cur_list['list_menu']['show_on']) && ($cur_list['list_menu']['show_on'] == 'both' || $cur_list['list_menu']['show_on'] == 'top'))
		template_colp_create_list_menu($cur_list['list_menu'], 'top');

	if (isset($cur_list['additional_rows']['top_of_list']))
		template_colp_additional_rows('top_of_list', $cur_list);

	if (isset($cur_list['additional_rows']['after_title']))
		template_colp_additional_rows('after_title', $cur_list);

	// Show the page index (if this list doesn't intend to show all items).
	if (!empty($cur_list['items_per_page']))
	{
		echo '
			<tr class="catbg">
				<td align="left" colspan="', $cur_list['num_columns'], '">
					<b>', $txt[139], ':</b> ', $cur_list['page_index'], '
				</td>
			</tr>';
	}

	if (isset($cur_list['additional_rows']['above_column_headers']))
		template_colp_additional_rows('above_column_headers', $cur_list);

	// Show the column headers.
	$header_count = count($cur_list['headers']);
	if (0 < $header_count)
	{
		echo '
			<tr class="titlebg">';

		// Loop through each column and add a table header.
		foreach ($cur_list['headers'] as $col_header)
		{
			echo '
				<td valign="top"', empty($col_header['class']) ? '' : ' class="' . $col_header['class'] . '"', empty($col_header['style']) ? '' : ' style="' . $col_header['style'] . '"', empty($col_header['colspan']) ? '' : ' colspan="' . $col_header['colspan'] . '"', '>',
					empty($col_header['href']) ? '' : '<a href="' . $col_header['href'] . '">',
					empty($col_header['label']) ? '&nbsp;' : $col_header['label'],
					empty($col_header['sort_image']) ? '' : ' <img src="' . $settings['images_url'] . '/sort_' . $col_header['sort_image'] . '.gif" alt="" />',
					empty($col_header['href']) ? '' : '</a>',
				'</td>';
		}

		echo '
			</tr>';
	}

	// Show a nice message informing there are no items in this list.
	if (empty($cur_list['rows']) && !empty($cur_list['no_items_label']))
	{
		echo '
			<tr>
				<td class="windowbg" colspan="', $cur_list['num_columns'], '" align="', !empty($cur_list['no_items_align']) ? $cur_list['no_items_align'] : 'center', '">', $cur_list['no_items_label'], '</td>
			</tr>';
	}

	// Show the list rows.
	elseif (!empty($cur_list['rows']))
	{
		$alternate = false;
		foreach ($cur_list['rows'] as $id => $row)
		{
			echo '
			<tr class="windowbg', $alternate ? '2' : '', '">';

			foreach ($row as $row_data)
				echo '
				<td', empty($row_data['class']) ? '' : ' class="' . $row_data['class'] . '"', empty($row_data['style']) ? '' : ' style="' . $row_data['style'] . '"', '>', $row_data['value'], '</td>';

			echo '
			</tr>';

			$alternate = !$alternate;
		}
	}

	// Show the page index (if this list doesn't intend to show all items).
	if (!empty($cur_list['items_per_page']))
	{
		echo '
			<tr class="catbg">
				<td align="left" colspan="', $cur_list['num_columns'], '">
					<b>', $txt[139], ':</b> ', $cur_list['page_index'], '
				</td>
			</tr>';
	}

	if (isset($cur_list['additional_rows']['below_table_data']))
		template_colp_additional_rows('below_table_data', $cur_list);

	if (isset($cur_list['additional_rows']['bottom_of_list']))
		template_colp_additional_rows('bottom_of_list', $cur_list);

	echo '
		</table>';

	if (isset($cur_list['form']))
	{
		foreach ($cur_list['form']['hidden_fields'] as $name => $value)
			echo '
		<input type="hidden" name="', $name, '" value="', $value, '" />';

		echo '
	</form>';
	}

	// Tabs at the bottom. Usually bottom aligned.
	if (!empty($settings['use_tabs']) && isset($cur_list['list_menu'], $cur_list['list_menu']['show_on']) && ($cur_list['list_menu']['show_on'] == 'both' || $cur_list['list_menu']['show_on'] == 'bottom'))
		template_colp_create_list_menu($cur_list['list_menu'], 'bottom');

	if (isset($cur_list['javascript']))
	{
		echo '
	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		', $cur_list['javascript'], '
	// ]]></script>';
	}
}

// Shows additional rows.
// Supported row positions: top_of_list, after_title,
// above_column_headers, below_table_data, bottom_of_list.
function template_colp_additional_rows($row_position, $cur_list)
{
	$class = 'after_title' == $row_position ? 'windowbg': 'windowbg2';
	$style = in_array($row_position, array('above_column_headers', 'below_table_data', 'bottom_of_list')) ? 'text-align: right;' : '';
	foreach ($cur_list['additional_rows'][$row_position] as $row)
	{
		echo '
		<tr class="', $class, empty($row['class']) ? '' : ' ' . $row['class'], '"', !empty($style) ? ' style="' . $style . '"' : '', '>
			<td colspan="', $cur_list['num_columns'], '"', empty($row['style']) ? '' : ' style="' . $row['style'] . '"', '>
				', $row['value'], '
			</td>
		</tr>';
	}
}

// Shows list menu.
function template_colp_create_list_menu($list_menu, $direction = 'top')
{
	global $settings;

	/*
		// This is use if you want your generic lists to have tabs.
		$list_menu = array(
			// This is used by the old styled menu.  We *need* to know the total number of columns to span.
			'columns' => 0,
			// This gives you the option to show tabs only at the top, bottom or both.
			// By default they are just shown at the top.
			'show_on' => 'top',
			// Links.  This is the core of the array.  It has all the info that we need.
			'links' => array(
				'name' => array(
					// This will tell use were to go when they click it.
					'href' => $scripturl . '?action=theaction',
					// The name that you want to appear for the link.
					'label' => $txt['name'],
					// If we use tabs instead of buttons we highlight the current tab.
					// Must use conditions to determine if its selected or not.
					'is_selected' => isset($_REQUEST['name']),
				),
			),
		);
	*/

	if (!empty($settings['use_tabs'])) // {'top', 'bottom'} == $direction.
	{
		$class_prefix = 'bottom' == $direction ? 'main' : 'mirror';
		echo '
	<table cellpadding="0" cellspacing="0" border="0" style="margin-left: 10px;">
		<tr>
			<td class="', $class_prefix, 'tab_first">&nbsp;</td>';

		foreach ($list_menu['links'] as $link)
		{
			if ($link['selected'])
			{
				echo '
				<td class="', $class_prefix, 'tab_active_first">&nbsp;</td>
				<td valign="top" class="', $class_prefix, 'tab_active_back">
					<a href="', $link['href'], '">', $link['label'], '</a>
				</td>
				<td class="', $class_prefix, 'tab_active_last">&nbsp;</td>';
			}
			else
			{
				echo '
				<td valign="top" class="', $class_prefix, 'tab_back">
					<a href="', $link['href'], '">', $link['label'], '</a>
				</td>';
			}
		}

		echo '
			<td class="', $class_prefix, 'tab_last">&nbsp;</td>
		</tr>
	</table>';
	}
	else // 'top' == $direction.
	{
		$links = array();
		foreach ($list_menu['links'] as $link)
			$links[] = ($link['selected'] ? '<img src="' . $settings['images_url'] . '/selected.gif" alt="&gt;" /> ' : '') . '<a href="' . $link['href'] . '">' . $link['label'] . '</a>';

		echo '
		<tr class="titlebg">
			<td colspan="', $list_menu['columns'], '">
				', implode(' | ', $links), '
			</td>
		</tr>';
	}
}

?>